{% extends base %}
{% load cms %}
{% block main_content %}
<form action="{{ action_url }}" method="post" class="publish">
        {% csrf_token %}
    {% bundle_url bundle "main_list" as cancel_url %}
        {% ifequal queryset|length 1 %}
            <p>{{ conf_msg }} <strong class="object-name">{{ queryset.0 }}</stong></p>
        {% else %}
            <p>{{ conf_msg }}</p>
            <ul>
            {% for obj in queryset %}
                <li class="object-name">{{ obj }}
                    <em>{% if item.is_published %}Currently live, {% else %}Currently not live,{% endif %}
                        {{ obj.status_line }}</em>
                </li>
            {% endfor %}
            </ul>
        {% endifequal %}
    {{ publish_form }}
    <div class="button-group button-group--submit">
        <a class="button button--secondary" href="{{ cancel_url }} ">Cancel</a>
        <input class="button button--primary" type="submit" name='modify' value="{{ action }}" />
    </div>
</form>
{% endblock %}
