{% extends "cms/base_site.html" %}
{% load i18n static %}
{% block userlinks %}{% trans 'Change password' %} / <a href="{% url 'admin:cms_logout' %}">{% trans 'Log out' %}</a>{% endblock %}

{% block title %}{% trans 'Password change' %}{% endblock %}

{% block content %}
<form action="" method="post">{% csrf_token %}
{% if form.errors %}
    <p class="errornote">
    {% blocktrans count counter=form.errors.items|length %}Please correct the error below.{% plural %}Please correct the errors below.{% endblocktrans %}
    </p>
{% endif %}

<header>
  <h2>{% trans 'Password change' %}</h2>
  <p>{% trans "Please enter your old password, for security's sake, and then enter your new password twice so we can verify you typed it in correctly." %}</p>
</header>
<div class="field-row">
    {{ form.old_password.errors }}
    <label for="id_old_password" class="required">{% trans 'Old password' %}:</label>{{ form.old_password }}
</div>

<div class="field-row">
    {{ form.new_password1.errors }}
    <label for="id_new_password1" class="required">{% trans 'New password' %}:</label>{{ form.new_password1 }}
</div>

<div class="field-row">
{{ form.new_password2.errors }}
    <label for="id_new_password2" class="required">{% trans 'Password (again)' %}:</label>{{ form.new_password2 }}
</div>

<div class="button-group button-group--submit">
  <a class="button button--secondary" href="{% url 'admin:cms_index' %}">Cancel</a>
  <input class="button button--primary" type="submit" value="{% trans 'Change my password' %}" class="default" />
</div>

<script type="text/javascript">document.getElementById("id_old_password").focus();</script>
</form>

{% endblock %}
