<div class="editor__toolbar">
  <div class="editor__buttons">
    <a data-wysihtml-command="bold" title="bold (ctrl+b)"><i class="fa fa-bold" aria-hidden="true"></i></a>
    <a data-wysihtml-command="italic" title="italic (ctrl+i)"><i class="fa fa-italic" aria-hidden="true"></i></a>
    <a data-wysihtml-command="createLink" title="link"><i class="fa fa-link" aria-hidden="true"></i></a>
    <a><i class="fa fa-chain-broken unlink" aria-hidden="true"></i></a>
    <a data-wysihtml-command="formatBlock" data-wysihtml-command-value="h1" title="heading 1">h<sup>1</sup></a>
    <a data-wysihtml-command="formatBlock" data-wysihtml-command-value="h2" title="heading 2">h<sup>2</sup></a>
    <a data-wysihtml-command="formatBlock" data-wysihtml-command-value="h3" title="heading 3">h<sup>3</sup></a>
    <a data-wysihtml-command="formatBlock" data-wysihtml-command-value="h4" title="heading 4">h<sup>4</sup></a>
    <a data-wysihtml-command="formatBlock" data-wysihtml-command-value="blockquote" title="blockquote"><i class="fa fa-quote-left" aria-hidden="true"></i></a>
    <a class="spacer" data-wysihtml-command="formatBlock" data-wysihtml-command-value="p" title="paragraph"><i class="fa fa-paragraph" aria-hidden="true"></i></a>
    <a data-wysihtml-command="insertUnorderedList" title="bulleted list"><i class="fa fa-list-ul" aria-hidden="true"></i></a>
    <a class="spacer" data-wysihtml-command="insertOrderedList" title="ordered list"><i class="fa fa-list-ol" aria-hidden="true"></i></a>
    <a data-wysihtml-command="undo" title="undo"><i class="fa fa-rotate-left" aria-hidden="true"></i></a>
    <a class="spacer" data-wysihtml-command="redo" title="redo"><i class="fa fa-rotate-right" aria-hidden="true"></i></a>
    <a class="spacer" data-wysihtml-action="change_view" title="view html"><i class="fa fa-code" aria-hidden="true"></i></a>
    <a data-wysihtml-command="insertImage" data-wysihtml-command-value='{"mediaUrl":"{% url 'admin:wysiwyg' %}"}'>insert media</a>
  </div>
  <div class="editor__modals">
    <div class="editor__modal" data-wysihtml-dialog="createLink" style="display: none;">
      <label>Enter link
        <input data-wysihtml-dialog-field="href" value="http://" class="text">
      </label>
      <div class="button-group button-group--submit">
        <a data-wysihtml-dialog-action="cancel" class="button button--secondary">Cancel</a>
        <a data-wysihtml-dialog-action="save" class="button button--primary">OK</a>
      </div>
    </div>
  </div>
</div>
