from .. import Provider as BaseProvider


# Reference:
# https://th.wikipedia.org/wiki/หมวดหมู่:บุคคลแบ่งตามอาชีพ
# on 2018-10-16
class Provider(BaseProvider):
    jobs = [
        'นักกฎหมาย',
        'กวี',
        'นักการทูต',
        'นักการเมือง',
        'นักการศึกษา',
        'นักกีฬา',
        'นักการกุศล',
        'เกษตรกร',
        'นักเขียน',
        'ข้าราชการ',
        'นักคณิตศาสตร์',
        'คนขับรถแท็กซี่',
        'โฆษก',
        'จ๊อกกี้',
        'นักจัดรายการวิทยุ',
        'จารชน',
        'จิตรกร',
        'นักจิตวิทยา',
        'เจ้าหน้าทีรักษาความปลอดภัย',
        'เจ้าหน้าที่รัฐบาล',
        'ช่างทำเครื่องดนตรี',
        'ช่างทำผม',
        'นักชีววิทยา',
        'นักดนตรี',
        'นักดาราศาสตร์',
        'นักแต่งเพลง',
        'ตำรวจ',
        'นักถ่ายภาพ',
        'ทนายความ',
        'ทหารบก',
        'นักธุรกิจ',
        'นักเคลื่อนไหว',
        'นักบวช',
        'นักบิน',
        'นักบินอวกาศ',
        'นักประชาสัมพันธ์',
        'นักผจญภัย',
        'นักสะสมศิลปะ',
        'นักแสดง',
        'นักหนังสือพิมพ์',
        'นางงาม',
        'นางแบบ',
        'นายแบบ',
        'บรรณาธิการ',
        'นักโบราณคดี',
        'นักแปล',
        'นักประดิษฐ์',
        'นักประวัติศาสตร์',
        'นักปรัชญา',
        'ผู้กำกับ',
        'ผู้กำกับภาพยนตร์',
        'ผู้กำกับละครโทรทัศน์',
        'ผู้จัดพิมพ์',
        'นักพจนานุกรม',
        'แพทย์',
        'นักพากย์',
        'พิธีกร',
        'นักโภชนาการ',
        'นักภาษาศาสตร์',
        'เภสัชกร',
        'มัคคุเทศก์',
        'นักมายากล',
        'นักวาดการ์ตูน',
        'นักวิทยาศาสตร์',
        'วิศวกร',
        'วีเจ',
        'นักเศรษฐศาสตร์',
        'ศิลปิน',
        'สถาปนิก',
        'นักสังคมวิทยา',
        'นักสังคมศาสตร์',
        'นักสัตววิทยา',
        'นักสำรวจ',
        'นักสืบ',
        'นักอนุรักษ์ธรรมชาติ',
        'นักออกแบบ',
        'อัยการ',
        'โปรแกรมเมอร์',
    ]
