@import url(//fonts.googleapis.com/css?family=Julius+Sans+One);@import url(//fonts.googleapis.com/css?family=Raleway:300,400,600);@import url(//fonts.googleapis.com/css?family=Open+Sans:400,600);/*!
 * jQuery UI CSS Framework 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/theming/
 */

/* Layout helpers
----------------------------------*/
.ui-helper-hidden {
	display: none;
}
.ui-helper-hidden-accessible {
	border: 0;
	clip: rect(0 0 0 0);
	height: 1px;
	margin: -1px;
	overflow: hidden;
	padding: 0;
	position: absolute;
	width: 1px;
}
.ui-helper-reset {
	margin: 0;
	padding: 0;
	border: 0;
	outline: 0;
	line-height: 1.3;
	text-decoration: none;
	font-size: 100%;
	list-style: none;
}
.ui-helper-clearfix:before,
.ui-helper-clearfix:after {
	content: "";
	display: table;
	border-collapse: collapse;
}
.ui-helper-clearfix:after {
	clear: both;
}
.ui-helper-zfix {
	width: 100%;
	height: 100%;
	top: 0;
	left: 0;
	position: absolute;
	opacity: 0;
	filter:Alpha(Opacity=0); /* support: IE8 */
}

.ui-front {
	z-index: 100;
}


/* Interaction Cues
----------------------------------*/
.ui-state-disabled {
	cursor: default !important;
	pointer-events: none;
}


/* Icons
----------------------------------*/
.ui-icon {
	display: inline-block;
	vertical-align: middle;
	margin-top: -.25em;
	position: relative;
	text-indent: -99999px;
	overflow: hidden;
	background-repeat: no-repeat;
}

.ui-widget-icon-block {
	left: 50%;
	margin-left: -8px;
	display: block;
}

/* Misc visuals
----------------------------------*/

/* Overlays */
.ui-widget-overlay {
	position: fixed;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
}
/*!
 * jQuery UI Accordion 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/accordion/#theming
 */
.ui-accordion .ui-accordion-header {
	display: block;
	cursor: pointer;
	position: relative;
	margin: 2px 0 0 0;
	padding: .5em .5em .5em .7em;
	font-size: 100%;
}
.ui-accordion .ui-accordion-content {
	padding: 1em 2.2em;
	border-top: 0;
	overflow: auto;
}
/*!
 * jQuery UI Autocomplete 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/autocomplete/#theming
 */
.ui-autocomplete {
	position: absolute;
	top: 0;
	left: 0;
	cursor: default;
}
/*!
 * jQuery UI Button 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/button/#theming
 */
.ui-button {
	padding: .4em 1em;
	display: inline-block;
	position: relative;
	line-height: normal;
	margin-right: .1em;
	cursor: pointer;
	vertical-align: middle;
	text-align: center;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;

	/* Support: IE <= 11 */
	overflow: visible;
}

.ui-button,
.ui-button:link,
.ui-button:visited,
.ui-button:hover,
.ui-button:active {
	text-decoration: none;
}

/* to make room for the icon, a width needs to be set here */
.ui-button-icon-only {
	width: 2em;
	box-sizing: border-box;
	text-indent: -9999px;
	white-space: nowrap;
}

/* no icon support for input elements */
input.ui-button.ui-button-icon-only {
	text-indent: 0;
}

/* button icon element(s) */
.ui-button-icon-only .ui-icon {
	position: absolute;
	top: 50%;
	left: 50%;
	margin-top: -8px;
	margin-left: -8px;
}

.ui-button.ui-icon-notext .ui-icon {
	padding: 0;
	width: 2.1em;
	height: 2.1em;
	text-indent: -9999px;
	white-space: nowrap;

}

input.ui-button.ui-icon-notext .ui-icon {
	width: auto;
	height: auto;
	text-indent: 0;
	white-space: normal;
	padding: .4em 1em;
}

/* workarounds */
/* Support: Firefox 5 - 40 */
input.ui-button::-moz-focus-inner,
button.ui-button::-moz-focus-inner {
	border: 0;
	padding: 0;
}
/*!
 * jQuery UI Checkboxradio 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/checkboxradio/#theming
 */

.ui-checkboxradio-label .ui-icon-background {
	box-shadow: inset 1px 1px 1px #ccc;
	border-radius: .12em;
	border: none;
}
.ui-checkboxradio-radio-label .ui-icon-background {
	width: 16px;
	height: 16px;
	border-radius: 1em;
	overflow: visible;
	border: none;
}
.ui-checkboxradio-radio-label.ui-checkboxradio-checked .ui-icon,
.ui-checkboxradio-radio-label.ui-checkboxradio-checked:hover .ui-icon {
	background-image: none;
	width: 8px;
	height: 8px;
	border-width: 4px;
	border-style: solid;
}
.ui-checkboxradio-disabled {
	pointer-events: none;
}
/*!
 * jQuery UI Controlgroup 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/controlgroup/#theming
 */

.ui-controlgroup {
	vertical-align: middle;
	display: inline-block;
}
.ui-controlgroup > .ui-controlgroup-item {
	float: left;
	margin-left: 0;
	margin-right: 0;
}
.ui-controlgroup > .ui-controlgroup-item:focus,
.ui-controlgroup > .ui-controlgroup-item.ui-visual-focus {
	z-index: 9999;
}
.ui-controlgroup-vertical > .ui-controlgroup-item {
	display: block;
	float: none;
	width: 100%;
	margin-top: 0;
	margin-bottom: 0;
	text-align: left;
}
.ui-controlgroup-vertical .ui-controlgroup-item {
	box-sizing: border-box;
}
.ui-controlgroup .ui-controlgroup-label {
	padding: .4em 1em;
}
.ui-controlgroup .ui-controlgroup-label span {
	font-size: 80%;
}
.ui-controlgroup-horizontal .ui-controlgroup-label + .ui-controlgroup-item {
	border-left: none;
}
.ui-controlgroup-vertical .ui-controlgroup-label + .ui-controlgroup-item {
	border-top: none;
}
.ui-controlgroup-horizontal .ui-controlgroup-label.ui-widget-content {
	border-right: none;
}
.ui-controlgroup-vertical .ui-controlgroup-label.ui-widget-content {
	border-bottom: none;
}

/* Spinner specific style fixes */
.ui-controlgroup-vertical .ui-spinner-input {

	/* Support: IE8 only, Android < 4.4 only */
	width: 75%;
	width: calc( 100% - 2.4em );
}
.ui-controlgroup-vertical .ui-spinner .ui-spinner-up {
	border-top-style: solid;
}

/*!
 * jQuery UI Datepicker 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/datepicker/#theming
 */
.ui-datepicker {
	width: 17em;
	padding: .2em .2em 0;
	display: none;
}
.ui-datepicker .ui-datepicker-header {
	position: relative;
	padding: .2em 0;
}
.ui-datepicker .ui-datepicker-prev,
.ui-datepicker .ui-datepicker-next {
	position: absolute;
	top: 2px;
	width: 1.8em;
	height: 1.8em;
}
.ui-datepicker .ui-datepicker-prev-hover,
.ui-datepicker .ui-datepicker-next-hover {
	top: 1px;
}
.ui-datepicker .ui-datepicker-prev {
	left: 2px;
}
.ui-datepicker .ui-datepicker-next {
	right: 2px;
}
.ui-datepicker .ui-datepicker-prev-hover {
	left: 1px;
}
.ui-datepicker .ui-datepicker-next-hover {
	right: 1px;
}
.ui-datepicker .ui-datepicker-prev span,
.ui-datepicker .ui-datepicker-next span {
	display: block;
	position: absolute;
	left: 50%;
	margin-left: -8px;
	top: 50%;
	margin-top: -8px;
}
.ui-datepicker .ui-datepicker-title {
	margin: 0 2.3em;
	line-height: 1.8em;
	text-align: center;
}
.ui-datepicker .ui-datepicker-title select {
	font-size: 1em;
	margin: 1px 0;
}
.ui-datepicker select.ui-datepicker-month,
.ui-datepicker select.ui-datepicker-year {
	width: 45%;
}
.ui-datepicker table {
	width: 100%;
	font-size: .9em;
	border-collapse: collapse;
	margin: 0 0 .4em;
}
.ui-datepicker th {
	padding: .7em .3em;
	text-align: center;
	font-weight: bold;
	border: 0;
}
.ui-datepicker td {
	border: 0;
	padding: 1px;
}
.ui-datepicker td span,
.ui-datepicker td a {
	display: block;
	padding: .2em;
	text-align: right;
	text-decoration: none;
}
.ui-datepicker .ui-datepicker-buttonpane {
	background-image: none;
	margin: .7em 0 0 0;
	padding: 0 .2em;
	border-left: 0;
	border-right: 0;
	border-bottom: 0;
}
.ui-datepicker .ui-datepicker-buttonpane button {
	float: right;
	margin: .5em .2em .4em;
	cursor: pointer;
	padding: .2em .6em .3em .6em;
	width: auto;
	overflow: visible;
}
.ui-datepicker .ui-datepicker-buttonpane button.ui-datepicker-current {
	float: left;
}

/* with multiple calendars */
.ui-datepicker.ui-datepicker-multi {
	width: auto;
}
.ui-datepicker-multi .ui-datepicker-group {
	float: left;
}
.ui-datepicker-multi .ui-datepicker-group table {
	width: 95%;
	margin: 0 auto .4em;
}
.ui-datepicker-multi-2 .ui-datepicker-group {
	width: 50%;
}
.ui-datepicker-multi-3 .ui-datepicker-group {
	width: 33.3%;
}
.ui-datepicker-multi-4 .ui-datepicker-group {
	width: 25%;
}
.ui-datepicker-multi .ui-datepicker-group-last .ui-datepicker-header,
.ui-datepicker-multi .ui-datepicker-group-middle .ui-datepicker-header {
	border-left-width: 0;
}
.ui-datepicker-multi .ui-datepicker-buttonpane {
	clear: left;
}
.ui-datepicker-row-break {
	clear: both;
	width: 100%;
	font-size: 0;
}

/* RTL support */
.ui-datepicker-rtl {
	direction: rtl;
}
.ui-datepicker-rtl .ui-datepicker-prev {
	right: 2px;
	left: auto;
}
.ui-datepicker-rtl .ui-datepicker-next {
	left: 2px;
	right: auto;
}
.ui-datepicker-rtl .ui-datepicker-prev:hover {
	right: 1px;
	left: auto;
}
.ui-datepicker-rtl .ui-datepicker-next:hover {
	left: 1px;
	right: auto;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane {
	clear: right;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane button {
	float: left;
}
.ui-datepicker-rtl .ui-datepicker-buttonpane button.ui-datepicker-current,
.ui-datepicker-rtl .ui-datepicker-group {
	float: right;
}
.ui-datepicker-rtl .ui-datepicker-group-last .ui-datepicker-header,
.ui-datepicker-rtl .ui-datepicker-group-middle .ui-datepicker-header {
	border-right-width: 0;
	border-left-width: 1px;
}

/* Icons */
.ui-datepicker .ui-icon {
	display: block;
	text-indent: -99999px;
	overflow: hidden;
	background-repeat: no-repeat;
	left: .5em;
	top: .3em;
}
/*!
 * jQuery UI Dialog 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/dialog/#theming
 */
.ui-dialog {
	position: absolute;
	top: 0;
	left: 0;
	padding: .2em;
	outline: 0;
}
.ui-dialog .ui-dialog-titlebar {
	padding: .4em 1em;
	position: relative;
}
.ui-dialog .ui-dialog-title {
	float: left;
	margin: .1em 0;
	white-space: nowrap;
	width: 90%;
	overflow: hidden;
	text-overflow: ellipsis;
}
.ui-dialog .ui-dialog-titlebar-close {
	position: absolute;
	right: .3em;
	top: 50%;
	width: 20px;
	margin: -10px 0 0 0;
	padding: 1px;
	height: 20px;
}
.ui-dialog .ui-dialog-content {
	position: relative;
	border: 0;
	padding: .5em 1em;
	background: none;
	overflow: auto;
}
.ui-dialog .ui-dialog-buttonpane {
	text-align: left;
	border-width: 1px 0 0 0;
	background-image: none;
	margin-top: .5em;
	padding: .3em 1em .5em .4em;
}
.ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
	float: right;
}
.ui-dialog .ui-dialog-buttonpane button {
	margin: .5em .4em .5em 0;
	cursor: pointer;
}
.ui-dialog .ui-resizable-n {
	height: 2px;
	top: 0;
}
.ui-dialog .ui-resizable-e {
	width: 2px;
	right: 0;
}
.ui-dialog .ui-resizable-s {
	height: 2px;
	bottom: 0;
}
.ui-dialog .ui-resizable-w {
	width: 2px;
	left: 0;
}
.ui-dialog .ui-resizable-se,
.ui-dialog .ui-resizable-sw,
.ui-dialog .ui-resizable-ne,
.ui-dialog .ui-resizable-nw {
	width: 7px;
	height: 7px;
}
.ui-dialog .ui-resizable-se {
	right: 0;
	bottom: 0;
}
.ui-dialog .ui-resizable-sw {
	left: 0;
	bottom: 0;
}
.ui-dialog .ui-resizable-ne {
	right: 0;
	top: 0;
}
.ui-dialog .ui-resizable-nw {
	left: 0;
	top: 0;
}
.ui-draggable .ui-dialog-titlebar {
	cursor: move;
}
/*!
 * jQuery UI Draggable 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */
.ui-draggable-handle {
	-ms-touch-action: none;
	touch-action: none;
}
/*!
 * jQuery UI Menu 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/menu/#theming
 */
.ui-menu {
	list-style: none;
	padding: 0;
	margin: 0;
	display: block;
	outline: 0;
}
.ui-menu .ui-menu {
	position: absolute;
}
.ui-menu .ui-menu-item {
	margin: 0;
	cursor: pointer;
	/* support: IE10, see #8844 */
	list-style-image: url("data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7");
}
.ui-menu .ui-menu-item-wrapper {
	position: relative;
	padding: 3px 1em 3px .4em;
}
.ui-menu .ui-menu-divider {
	margin: 5px 0;
	height: 0;
	font-size: 0;
	line-height: 0;
	border-width: 1px 0 0 0;
}
.ui-menu .ui-state-focus,
.ui-menu .ui-state-active {
	margin: -1px;
}

/* icon support */
.ui-menu-icons {
	position: relative;
}
.ui-menu-icons .ui-menu-item-wrapper {
	padding-left: 2em;
}

/* left-aligned */
.ui-menu .ui-icon {
	position: absolute;
	top: 0;
	bottom: 0;
	left: .2em;
	margin: auto 0;
}

/* right-aligned */
.ui-menu .ui-menu-icon {
	left: auto;
	right: 0;
}
/*!
 * jQuery UI Progressbar 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/progressbar/#theming
 */
.ui-progressbar {
	height: 2em;
	text-align: left;
	overflow: hidden;
}
.ui-progressbar .ui-progressbar-value {
	margin: -1px;
	height: 100%;
}
.ui-progressbar .ui-progressbar-overlay {
	background: url("data:image/gif;base64,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");
	height: 100%;
	filter: alpha(opacity=25); /* support: IE8 */
	opacity: 0.25;
}
.ui-progressbar-indeterminate .ui-progressbar-value {
	background-image: none;
}
/*!
 * jQuery UI Resizable 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */
.ui-resizable {
	position: relative;
}
.ui-resizable-handle {
	position: absolute;
	font-size: 0.1px;
	display: block;
	-ms-touch-action: none;
	touch-action: none;
}
.ui-resizable-disabled .ui-resizable-handle,
.ui-resizable-autohide .ui-resizable-handle {
	display: none;
}
.ui-resizable-n {
	cursor: n-resize;
	height: 7px;
	width: 100%;
	top: -5px;
	left: 0;
}
.ui-resizable-s {
	cursor: s-resize;
	height: 7px;
	width: 100%;
	bottom: -5px;
	left: 0;
}
.ui-resizable-e {
	cursor: e-resize;
	width: 7px;
	right: -5px;
	top: 0;
	height: 100%;
}
.ui-resizable-w {
	cursor: w-resize;
	width: 7px;
	left: -5px;
	top: 0;
	height: 100%;
}
.ui-resizable-se {
	cursor: se-resize;
	width: 12px;
	height: 12px;
	right: 1px;
	bottom: 1px;
}
.ui-resizable-sw {
	cursor: sw-resize;
	width: 9px;
	height: 9px;
	left: -5px;
	bottom: -5px;
}
.ui-resizable-nw {
	cursor: nw-resize;
	width: 9px;
	height: 9px;
	left: -5px;
	top: -5px;
}
.ui-resizable-ne {
	cursor: ne-resize;
	width: 9px;
	height: 9px;
	right: -5px;
	top: -5px;
}
/*!
 * jQuery UI Selectable 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */
.ui-selectable {
	-ms-touch-action: none;
	touch-action: none;
}
.ui-selectable-helper {
	position: absolute;
	z-index: 100;
	border: 1px dotted black;
}
/*!
 * jQuery UI Selectmenu 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/selectmenu/#theming
 */
.ui-selectmenu-menu {
	padding: 0;
	margin: 0;
	position: absolute;
	top: 0;
	left: 0;
	display: none;
}
.ui-selectmenu-menu .ui-menu {
	overflow: auto;
	overflow-x: hidden;
	padding-bottom: 1px;
}
.ui-selectmenu-menu .ui-menu .ui-selectmenu-optgroup {
	font-size: 1em;
	font-weight: bold;
	line-height: 1.5;
	padding: 2px 0.4em;
	margin: 0.5em 0 0 0;
	height: auto;
	border: 0;
}
.ui-selectmenu-open {
	display: block;
}
.ui-selectmenu-text {
	display: block;
	margin-right: 20px;
	overflow: hidden;
	text-overflow: ellipsis;
}
.ui-selectmenu-button.ui-button {
	text-align: left;
	white-space: nowrap;
	width: 14em;
}
.ui-selectmenu-icon.ui-icon {
	float: right;
	margin-top: 0;
}
/*!
 * jQuery UI Sortable 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 */
.ui-sortable-handle {
	-ms-touch-action: none;
	touch-action: none;
}
/*!
 * jQuery UI Slider 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/slider/#theming
 */
.ui-slider {
	position: relative;
	text-align: left;
}
.ui-slider .ui-slider-handle {
	position: absolute;
	z-index: 2;
	width: 1.2em;
	height: 1.2em;
	cursor: default;
	-ms-touch-action: none;
	touch-action: none;
}
.ui-slider .ui-slider-range {
	position: absolute;
	z-index: 1;
	font-size: .7em;
	display: block;
	border: 0;
	background-position: 0 0;
}

/* support: IE8 - See #6727 */
.ui-slider.ui-state-disabled .ui-slider-handle,
.ui-slider.ui-state-disabled .ui-slider-range {
	filter: inherit;
}

.ui-slider-horizontal {
	height: .8em;
}
.ui-slider-horizontal .ui-slider-handle {
	top: -.3em;
	margin-left: -.6em;
}
.ui-slider-horizontal .ui-slider-range {
	top: 0;
	height: 100%;
}
.ui-slider-horizontal .ui-slider-range-min {
	left: 0;
}
.ui-slider-horizontal .ui-slider-range-max {
	right: 0;
}

.ui-slider-vertical {
	width: .8em;
	height: 100px;
}
.ui-slider-vertical .ui-slider-handle {
	left: -.3em;
	margin-left: 0;
	margin-bottom: -.6em;
}
.ui-slider-vertical .ui-slider-range {
	left: 0;
	width: 100%;
}
.ui-slider-vertical .ui-slider-range-min {
	bottom: 0;
}
.ui-slider-vertical .ui-slider-range-max {
	top: 0;
}
/*!
 * jQuery UI Spinner 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/spinner/#theming
 */
.ui-spinner {
	position: relative;
	display: inline-block;
	overflow: hidden;
	padding: 0;
	vertical-align: middle;
}
.ui-spinner-input {
	border: none;
	background: none;
	color: inherit;
	padding: .222em 0;
	margin: .2em 0;
	vertical-align: middle;
	margin-left: .4em;
	margin-right: 2em;
}
.ui-spinner-button {
	width: 1.6em;
	height: 50%;
	font-size: .5em;
	padding: 0;
	margin: 0;
	text-align: center;
	position: absolute;
	cursor: default;
	display: block;
	overflow: hidden;
	right: 0;
}
/* more specificity required here to override default borders */
.ui-spinner a.ui-spinner-button {
	border-top-style: none;
	border-bottom-style: none;
	border-right-style: none;
}
.ui-spinner-up {
	top: 0;
}
.ui-spinner-down {
	bottom: 0;
}
/*!
 * jQuery UI Tabs 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/tabs/#theming
 */
.ui-tabs {
	position: relative;/* position: relative prevents IE scroll bug (element with position: relative inside container with overflow: auto appear as "fixed") */
	padding: .2em;
}
.ui-tabs .ui-tabs-nav {
	margin: 0;
	padding: .2em .2em 0;
}
.ui-tabs .ui-tabs-nav li {
	list-style: none;
	float: left;
	position: relative;
	top: 0;
	margin: 1px .2em 0 0;
	border-bottom-width: 0;
	padding: 0;
	white-space: nowrap;
}
.ui-tabs .ui-tabs-nav .ui-tabs-anchor {
	float: left;
	padding: .5em 1em;
	text-decoration: none;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active {
	margin-bottom: -1px;
	padding-bottom: 1px;
}
.ui-tabs .ui-tabs-nav li.ui-tabs-active .ui-tabs-anchor,
.ui-tabs .ui-tabs-nav li.ui-state-disabled .ui-tabs-anchor,
.ui-tabs .ui-tabs-nav li.ui-tabs-loading .ui-tabs-anchor {
	cursor: text;
}
.ui-tabs-collapsible .ui-tabs-nav li.ui-tabs-active .ui-tabs-anchor {
	cursor: pointer;
}
.ui-tabs .ui-tabs-panel {
	display: block;
	border-width: 0;
	padding: 1em 1.4em;
	background: none;
}
/*!
 * jQuery UI Tooltip 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/tooltip/#theming
 */
.ui-tooltip {
	padding: 8px;
	position: absolute;
	z-index: 9999;
	max-width: 300px;
}
body .ui-tooltip {
	border-width: 2px;
}
/*!
 * jQuery UI CSS Framework 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/theming/
 */
/*!
 * jQuery UI CSS Framework 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/theming/
 *
 * To view and modify this theme, visit http://jqueryui.com/themeroller/
 */


/* Component containers
----------------------------------*/
.ui-widget {
	font-family: Arial,Helvetica,sans-serif/*{ffDefault}*/;
	font-size: 1em/*{fsDefault}*/;
}
.ui-widget .ui-widget {
	font-size: 1em;
}
.ui-widget input,
.ui-widget select,
.ui-widget textarea,
.ui-widget button {
	font-family: Arial,Helvetica,sans-serif/*{ffDefault}*/;
	font-size: 1em;
}
.ui-widget.ui-widget-content {
	border: 1px solid #c5c5c5/*{borderColorDefault}*/;
}
.ui-widget-content {
	border: 1px solid #dddddd/*{borderColorContent}*/;
	background: #ffffff/*{bgColorContent}*/ /*{bgImgUrlContent}*/ /*{bgContentXPos}*/ /*{bgContentYPos}*/ /*{bgContentRepeat}*/;
	color: #333333/*{fcContent}*/;
}
.ui-widget-content a {
	color: #333333/*{fcContent}*/;
}
.ui-widget-header {
	border: 1px solid #dddddd/*{borderColorHeader}*/;
	background: #e9e9e9/*{bgColorHeader}*/ /*{bgImgUrlHeader}*/ /*{bgHeaderXPos}*/ /*{bgHeaderYPos}*/ /*{bgHeaderRepeat}*/;
	color: #333333/*{fcHeader}*/;
	font-weight: bold;
}
.ui-widget-header a {
	color: #333333/*{fcHeader}*/;
}

/* Interaction states
----------------------------------*/
.ui-state-default,
.ui-widget-content .ui-state-default,
.ui-widget-header .ui-state-default,
.ui-button,

/* We use html here because we need a greater specificity to make sure disabled
works properly when clicked or hovered */
html .ui-button.ui-state-disabled:hover,
html .ui-button.ui-state-disabled:active {
	border: 1px solid #c5c5c5/*{borderColorDefault}*/;
	background: #f6f6f6/*{bgColorDefault}*/ /*{bgImgUrlDefault}*/ /*{bgDefaultXPos}*/ /*{bgDefaultYPos}*/ /*{bgDefaultRepeat}*/;
	font-weight: normal/*{fwDefault}*/;
	color: #454545/*{fcDefault}*/;
}
.ui-state-default a,
.ui-state-default a:link,
.ui-state-default a:visited,
a.ui-button,
a:link.ui-button,
a:visited.ui-button,
.ui-button {
	color: #454545/*{fcDefault}*/;
	text-decoration: none;
}
.ui-state-hover,
.ui-widget-content .ui-state-hover,
.ui-widget-header .ui-state-hover,
.ui-state-focus,
.ui-widget-content .ui-state-focus,
.ui-widget-header .ui-state-focus,
.ui-button:hover,
.ui-button:focus {
	border: 1px solid #cccccc/*{borderColorHover}*/;
	background: #ededed/*{bgColorHover}*/ /*{bgImgUrlHover}*/ /*{bgHoverXPos}*/ /*{bgHoverYPos}*/ /*{bgHoverRepeat}*/;
	font-weight: normal/*{fwDefault}*/;
	color: #2b2b2b/*{fcHover}*/;
}
.ui-state-hover a,
.ui-state-hover a:hover,
.ui-state-hover a:link,
.ui-state-hover a:visited,
.ui-state-focus a,
.ui-state-focus a:hover,
.ui-state-focus a:link,
.ui-state-focus a:visited,
a.ui-button:hover,
a.ui-button:focus {
	color: #2b2b2b/*{fcHover}*/;
	text-decoration: none;
}

.ui-visual-focus {
	box-shadow: 0 0 3px 1px rgb(94, 158, 214);
}
.ui-state-active,
.ui-widget-content .ui-state-active,
.ui-widget-header .ui-state-active,
a.ui-button:active,
.ui-button:active,
.ui-button.ui-state-active:hover {
	border: 1px solid #003eff/*{borderColorActive}*/;
	background: #007fff/*{bgColorActive}*/ /*{bgImgUrlActive}*/ /*{bgActiveXPos}*/ /*{bgActiveYPos}*/ /*{bgActiveRepeat}*/;
	font-weight: normal/*{fwDefault}*/;
	color: #ffffff/*{fcActive}*/;
}
.ui-icon-background,
.ui-state-active .ui-icon-background {
	border: #003eff/*{borderColorActive}*/;
	background-color: #ffffff/*{fcActive}*/;
}
.ui-state-active a,
.ui-state-active a:link,
.ui-state-active a:visited {
	color: #ffffff/*{fcActive}*/;
	text-decoration: none;
}

/* Interaction Cues
----------------------------------*/
.ui-state-highlight,
.ui-widget-content .ui-state-highlight,
.ui-widget-header .ui-state-highlight {
	border: 1px solid #dad55e/*{borderColorHighlight}*/;
	background: #fffa90/*{bgColorHighlight}*/ /*{bgImgUrlHighlight}*/ /*{bgHighlightXPos}*/ /*{bgHighlightYPos}*/ /*{bgHighlightRepeat}*/;
	color: #777620/*{fcHighlight}*/;
}
.ui-state-checked {
	border: 1px solid #dad55e/*{borderColorHighlight}*/;
	background: #fffa90/*{bgColorHighlight}*/;
}
.ui-state-highlight a,
.ui-widget-content .ui-state-highlight a,
.ui-widget-header .ui-state-highlight a {
	color: #777620/*{fcHighlight}*/;
}
.ui-state-error,
.ui-widget-content .ui-state-error,
.ui-widget-header .ui-state-error {
	border: 1px solid #f1a899/*{borderColorError}*/;
	background: #fddfdf/*{bgColorError}*/ /*{bgImgUrlError}*/ /*{bgErrorXPos}*/ /*{bgErrorYPos}*/ /*{bgErrorRepeat}*/;
	color: #5f3f3f/*{fcError}*/;
}
.ui-state-error a,
.ui-widget-content .ui-state-error a,
.ui-widget-header .ui-state-error a {
	color: #5f3f3f/*{fcError}*/;
}
.ui-state-error-text,
.ui-widget-content .ui-state-error-text,
.ui-widget-header .ui-state-error-text {
	color: #5f3f3f/*{fcError}*/;
}
.ui-priority-primary,
.ui-widget-content .ui-priority-primary,
.ui-widget-header .ui-priority-primary {
	font-weight: bold;
}
.ui-priority-secondary,
.ui-widget-content .ui-priority-secondary,
.ui-widget-header .ui-priority-secondary {
	opacity: .7;
	filter:Alpha(Opacity=70); /* support: IE8 */
	font-weight: normal;
}
.ui-state-disabled,
.ui-widget-content .ui-state-disabled,
.ui-widget-header .ui-state-disabled {
	opacity: .35;
	filter:Alpha(Opacity=35); /* support: IE8 */
	background-image: none;
}
.ui-state-disabled .ui-icon {
	filter:Alpha(Opacity=35); /* support: IE8 - See #6059 */
}

/* Icons
----------------------------------*/

/* states and images */
.ui-icon {
	width: 16px;
	height: 16px;
}
.ui-icon,
.ui-widget-content .ui-icon {
	background-image: url(/static/images/ui-icons_444444_256x240.png);
}
.ui-widget-header .ui-icon {
	background-image: url(/static/images/ui-icons_444444_256x240.png);
}
.ui-state-hover .ui-icon,
.ui-state-focus .ui-icon,
.ui-button:hover .ui-icon,
.ui-button:focus .ui-icon {
	background-image: url(/static/images/ui-icons_555555_256x240.png);
}
.ui-state-active .ui-icon,
.ui-button:active .ui-icon {
	background-image: url(/static/images/ui-icons_ffffff_256x240.png);
}
.ui-state-highlight .ui-icon,
.ui-button .ui-state-highlight.ui-icon {
	background-image: url(/static/images/ui-icons_777620_256x240.png);
}
.ui-state-error .ui-icon,
.ui-state-error-text .ui-icon {
	background-image: url(/static/images/ui-icons_cc0000_256x240.png);
}
.ui-button .ui-icon {
	background-image: url(/static/images/ui-icons_777777_256x240.png);
}

/* positioning */
.ui-icon-blank { background-position: 16px 16px; }
.ui-icon-caret-1-n { background-position: 0 0; }
.ui-icon-caret-1-ne { background-position: -16px 0; }
.ui-icon-caret-1-e { background-position: -32px 0; }
.ui-icon-caret-1-se { background-position: -48px 0; }
.ui-icon-caret-1-s { background-position: -65px 0; }
.ui-icon-caret-1-sw { background-position: -80px 0; }
.ui-icon-caret-1-w { background-position: -96px 0; }
.ui-icon-caret-1-nw { background-position: -112px 0; }
.ui-icon-caret-2-n-s { background-position: -128px 0; }
.ui-icon-caret-2-e-w { background-position: -144px 0; }
.ui-icon-triangle-1-n { background-position: 0 -16px; }
.ui-icon-triangle-1-ne { background-position: -16px -16px; }
.ui-icon-triangle-1-e { background-position: -32px -16px; }
.ui-icon-triangle-1-se { background-position: -48px -16px; }
.ui-icon-triangle-1-s { background-position: -65px -16px; }
.ui-icon-triangle-1-sw { background-position: -80px -16px; }
.ui-icon-triangle-1-w { background-position: -96px -16px; }
.ui-icon-triangle-1-nw { background-position: -112px -16px; }
.ui-icon-triangle-2-n-s { background-position: -128px -16px; }
.ui-icon-triangle-2-e-w { background-position: -144px -16px; }
.ui-icon-arrow-1-n { background-position: 0 -32px; }
.ui-icon-arrow-1-ne { background-position: -16px -32px; }
.ui-icon-arrow-1-e { background-position: -32px -32px; }
.ui-icon-arrow-1-se { background-position: -48px -32px; }
.ui-icon-arrow-1-s { background-position: -65px -32px; }
.ui-icon-arrow-1-sw { background-position: -80px -32px; }
.ui-icon-arrow-1-w { background-position: -96px -32px; }
.ui-icon-arrow-1-nw { background-position: -112px -32px; }
.ui-icon-arrow-2-n-s { background-position: -128px -32px; }
.ui-icon-arrow-2-ne-sw { background-position: -144px -32px; }
.ui-icon-arrow-2-e-w { background-position: -160px -32px; }
.ui-icon-arrow-2-se-nw { background-position: -176px -32px; }
.ui-icon-arrowstop-1-n { background-position: -192px -32px; }
.ui-icon-arrowstop-1-e { background-position: -208px -32px; }
.ui-icon-arrowstop-1-s { background-position: -224px -32px; }
.ui-icon-arrowstop-1-w { background-position: -240px -32px; }
.ui-icon-arrowthick-1-n { background-position: 1px -48px; }
.ui-icon-arrowthick-1-ne { background-position: -16px -48px; }
.ui-icon-arrowthick-1-e { background-position: -32px -48px; }
.ui-icon-arrowthick-1-se { background-position: -48px -48px; }
.ui-icon-arrowthick-1-s { background-position: -64px -48px; }
.ui-icon-arrowthick-1-sw { background-position: -80px -48px; }
.ui-icon-arrowthick-1-w { background-position: -96px -48px; }
.ui-icon-arrowthick-1-nw { background-position: -112px -48px; }
.ui-icon-arrowthick-2-n-s { background-position: -128px -48px; }
.ui-icon-arrowthick-2-ne-sw { background-position: -144px -48px; }
.ui-icon-arrowthick-2-e-w { background-position: -160px -48px; }
.ui-icon-arrowthick-2-se-nw { background-position: -176px -48px; }
.ui-icon-arrowthickstop-1-n { background-position: -192px -48px; }
.ui-icon-arrowthickstop-1-e { background-position: -208px -48px; }
.ui-icon-arrowthickstop-1-s { background-position: -224px -48px; }
.ui-icon-arrowthickstop-1-w { background-position: -240px -48px; }
.ui-icon-arrowreturnthick-1-w { background-position: 0 -64px; }
.ui-icon-arrowreturnthick-1-n { background-position: -16px -64px; }
.ui-icon-arrowreturnthick-1-e { background-position: -32px -64px; }
.ui-icon-arrowreturnthick-1-s { background-position: -48px -64px; }
.ui-icon-arrowreturn-1-w { background-position: -64px -64px; }
.ui-icon-arrowreturn-1-n { background-position: -80px -64px; }
.ui-icon-arrowreturn-1-e { background-position: -96px -64px; }
.ui-icon-arrowreturn-1-s { background-position: -112px -64px; }
.ui-icon-arrowrefresh-1-w { background-position: -128px -64px; }
.ui-icon-arrowrefresh-1-n { background-position: -144px -64px; }
.ui-icon-arrowrefresh-1-e { background-position: -160px -64px; }
.ui-icon-arrowrefresh-1-s { background-position: -176px -64px; }
.ui-icon-arrow-4 { background-position: 0 -80px; }
.ui-icon-arrow-4-diag { background-position: -16px -80px; }
.ui-icon-extlink { background-position: -32px -80px; }
.ui-icon-newwin { background-position: -48px -80px; }
.ui-icon-refresh { background-position: -64px -80px; }
.ui-icon-shuffle { background-position: -80px -80px; }
.ui-icon-transfer-e-w { background-position: -96px -80px; }
.ui-icon-transferthick-e-w { background-position: -112px -80px; }
.ui-icon-folder-collapsed { background-position: 0 -96px; }
.ui-icon-folder-open { background-position: -16px -96px; }
.ui-icon-document { background-position: -32px -96px; }
.ui-icon-document-b { background-position: -48px -96px; }
.ui-icon-note { background-position: -64px -96px; }
.ui-icon-mail-closed { background-position: -80px -96px; }
.ui-icon-mail-open { background-position: -96px -96px; }
.ui-icon-suitcase { background-position: -112px -96px; }
.ui-icon-comment { background-position: -128px -96px; }
.ui-icon-person { background-position: -144px -96px; }
.ui-icon-print { background-position: -160px -96px; }
.ui-icon-trash { background-position: -176px -96px; }
.ui-icon-locked { background-position: -192px -96px; }
.ui-icon-unlocked { background-position: -208px -96px; }
.ui-icon-bookmark { background-position: -224px -96px; }
.ui-icon-tag { background-position: -240px -96px; }
.ui-icon-home { background-position: 0 -112px; }
.ui-icon-flag { background-position: -16px -112px; }
.ui-icon-calendar { background-position: -32px -112px; }
.ui-icon-cart { background-position: -48px -112px; }
.ui-icon-pencil { background-position: -64px -112px; }
.ui-icon-clock { background-position: -80px -112px; }
.ui-icon-disk { background-position: -96px -112px; }
.ui-icon-calculator { background-position: -112px -112px; }
.ui-icon-zoomin { background-position: -128px -112px; }
.ui-icon-zoomout { background-position: -144px -112px; }
.ui-icon-search { background-position: -160px -112px; }
.ui-icon-wrench { background-position: -176px -112px; }
.ui-icon-gear { background-position: -192px -112px; }
.ui-icon-heart { background-position: -208px -112px; }
.ui-icon-star { background-position: -224px -112px; }
.ui-icon-link { background-position: -240px -112px; }
.ui-icon-cancel { background-position: 0 -128px; }
.ui-icon-plus { background-position: -16px -128px; }
.ui-icon-plusthick { background-position: -32px -128px; }
.ui-icon-minus { background-position: -48px -128px; }
.ui-icon-minusthick { background-position: -64px -128px; }
.ui-icon-close { background-position: -80px -128px; }
.ui-icon-closethick { background-position: -96px -128px; }
.ui-icon-key { background-position: -112px -128px; }
.ui-icon-lightbulb { background-position: -128px -128px; }
.ui-icon-scissors { background-position: -144px -128px; }
.ui-icon-clipboard { background-position: -160px -128px; }
.ui-icon-copy { background-position: -176px -128px; }
.ui-icon-contact { background-position: -192px -128px; }
.ui-icon-image { background-position: -208px -128px; }
.ui-icon-video { background-position: -224px -128px; }
.ui-icon-script { background-position: -240px -128px; }
.ui-icon-alert { background-position: 0 -144px; }
.ui-icon-info { background-position: -16px -144px; }
.ui-icon-notice { background-position: -32px -144px; }
.ui-icon-help { background-position: -48px -144px; }
.ui-icon-check { background-position: -64px -144px; }
.ui-icon-bullet { background-position: -80px -144px; }
.ui-icon-radio-on { background-position: -96px -144px; }
.ui-icon-radio-off { background-position: -112px -144px; }
.ui-icon-pin-w { background-position: -128px -144px; }
.ui-icon-pin-s { background-position: -144px -144px; }
.ui-icon-play { background-position: 0 -160px; }
.ui-icon-pause { background-position: -16px -160px; }
.ui-icon-seek-next { background-position: -32px -160px; }
.ui-icon-seek-prev { background-position: -48px -160px; }
.ui-icon-seek-end { background-position: -64px -160px; }
.ui-icon-seek-start { background-position: -80px -160px; }
/* ui-icon-seek-first is deprecated, use ui-icon-seek-start instead */
.ui-icon-seek-first { background-position: -80px -160px; }
.ui-icon-stop { background-position: -96px -160px; }
.ui-icon-eject { background-position: -112px -160px; }
.ui-icon-volume-off { background-position: -128px -160px; }
.ui-icon-volume-on { background-position: -144px -160px; }
.ui-icon-power { background-position: 0 -176px; }
.ui-icon-signal-diag { background-position: -16px -176px; }
.ui-icon-signal { background-position: -32px -176px; }
.ui-icon-battery-0 { background-position: -48px -176px; }
.ui-icon-battery-1 { background-position: -64px -176px; }
.ui-icon-battery-2 { background-position: -80px -176px; }
.ui-icon-battery-3 { background-position: -96px -176px; }
.ui-icon-circle-plus { background-position: 0 -192px; }
.ui-icon-circle-minus { background-position: -16px -192px; }
.ui-icon-circle-close { background-position: -32px -192px; }
.ui-icon-circle-triangle-e { background-position: -48px -192px; }
.ui-icon-circle-triangle-s { background-position: -64px -192px; }
.ui-icon-circle-triangle-w { background-position: -80px -192px; }
.ui-icon-circle-triangle-n { background-position: -96px -192px; }
.ui-icon-circle-arrow-e { background-position: -112px -192px; }
.ui-icon-circle-arrow-s { background-position: -128px -192px; }
.ui-icon-circle-arrow-w { background-position: -144px -192px; }
.ui-icon-circle-arrow-n { background-position: -160px -192px; }
.ui-icon-circle-zoomin { background-position: -176px -192px; }
.ui-icon-circle-zoomout { background-position: -192px -192px; }
.ui-icon-circle-check { background-position: -208px -192px; }
.ui-icon-circlesmall-plus { background-position: 0 -208px; }
.ui-icon-circlesmall-minus { background-position: -16px -208px; }
.ui-icon-circlesmall-close { background-position: -32px -208px; }
.ui-icon-squaresmall-plus { background-position: -48px -208px; }
.ui-icon-squaresmall-minus { background-position: -64px -208px; }
.ui-icon-squaresmall-close { background-position: -80px -208px; }
.ui-icon-grip-dotted-vertical { background-position: 0 -224px; }
.ui-icon-grip-dotted-horizontal { background-position: -16px -224px; }
.ui-icon-grip-solid-vertical { background-position: -32px -224px; }
.ui-icon-grip-solid-horizontal { background-position: -48px -224px; }
.ui-icon-gripsmall-diagonal-se { background-position: -64px -224px; }
.ui-icon-grip-diagonal-se { background-position: -80px -224px; }


/* Misc visuals
----------------------------------*/

/* Corner radius */
.ui-corner-all,
.ui-corner-top,
.ui-corner-left,
.ui-corner-tl {
	border-top-left-radius: 3px/*{cornerRadius}*/;
}
.ui-corner-all,
.ui-corner-top,
.ui-corner-right,
.ui-corner-tr {
	border-top-right-radius: 3px/*{cornerRadius}*/;
}
.ui-corner-all,
.ui-corner-bottom,
.ui-corner-left,
.ui-corner-bl {
	border-bottom-left-radius: 3px/*{cornerRadius}*/;
}
.ui-corner-all,
.ui-corner-bottom,
.ui-corner-right,
.ui-corner-br {
	border-bottom-right-radius: 3px/*{cornerRadius}*/;
}

/* Overlays */
.ui-widget-overlay {
	background: #aaaaaa/*{bgColorOverlay}*/ /*{bgImgUrlOverlay}*/ /*{bgOverlayXPos}*/ /*{bgOverlayYPos}*/ /*{bgOverlayRepeat}*/;
	opacity: .3/*{opacityOverlay}*/;
	filter: Alpha(Opacity=30)/*{opacityFilterOverlay}*/; /* support: IE8 */
}
.ui-widget-shadow {
	-webkit-box-shadow: 0/*{offsetLeftShadow}*/ 0/*{offsetTopShadow}*/ 5px/*{thicknessShadow}*/ #666666/*{bgColorShadow}*/;
	box-shadow: 0/*{offsetLeftShadow}*/ 0/*{offsetTopShadow}*/ 5px/*{thicknessShadow}*/ #666666/*{bgColorShadow}*/;
}
/*!
 * jQuery UI CSS Framework 1.12.1
 * http://jqueryui.com
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/theming/
 */
/**
 * selectize.default.css (v0.12.4) - Default Theme
 * Copyright (c) 2013–2015 Brian Reavis & contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain a copy of the License at:
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under
 * the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 * ANY KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 *
 * @author Brian Reavis <brian@thirdroute.com>
 */
.selectize-control.plugin-drag_drop.multi > .selectize-input > div.ui-sortable-placeholder {
  visibility: visible !important;
  background: #f2f2f2 !important;
  background: rgba(0, 0, 0, 0.06) !important;
  border: 0 none !important;
  -webkit-box-shadow: inset 0 0 12px 4px #ffffff;
  box-shadow: inset 0 0 12px 4px #ffffff;
}
.selectize-control.plugin-drag_drop .ui-sortable-placeholder::after {
  content: '!';
  visibility: hidden;
}
.selectize-control.plugin-drag_drop .ui-sortable-helper {
  -webkit-box-shadow: 0 2px 5px rgba(0, 0, 0, 0.2);
  box-shadow: 0 2px 5px rgba(0, 0, 0, 0.2);
}
.selectize-dropdown-header {
  position: relative;
  padding: 5px 8px;
  border-bottom: 1px solid #d0d0d0;
  background: #f8f8f8;
  -webkit-border-radius: 3px 3px 0 0;
  -moz-border-radius: 3px 3px 0 0;
  border-radius: 3px 3px 0 0;
}
.selectize-dropdown-header-close {
  position: absolute;
  right: 8px;
  top: 50%;
  color: #303030;
  opacity: 0.4;
  margin-top: -12px;
  line-height: 20px;
  font-size: 20px !important;
}
.selectize-dropdown-header-close:hover {
  color: #000000;
}
.selectize-dropdown.plugin-optgroup_columns .optgroup {
  border-right: 1px solid #f2f2f2;
  border-top: 0 none;
  float: left;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.selectize-dropdown.plugin-optgroup_columns .optgroup:last-child {
  border-right: 0 none;
}
.selectize-dropdown.plugin-optgroup_columns .optgroup:before {
  display: none;
}
.selectize-dropdown.plugin-optgroup_columns .optgroup-header {
  border-top: 0 none;
}
.selectize-control.plugin-remove_button [data-value] {
  position: relative;
  padding-right: 24px !important;
}
.selectize-control.plugin-remove_button [data-value] .remove {
  z-index: 1;
  /* fixes ie bug (see #392) */
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  width: 17px;
  text-align: center;
  font-weight: bold;
  font-size: 12px;
  color: inherit;
  text-decoration: none;
  vertical-align: middle;
  display: inline-block;
  padding: 2px 0 0 0;
  border-left: 1px solid #0073bb;
  -webkit-border-radius: 0 2px 2px 0;
  -moz-border-radius: 0 2px 2px 0;
  border-radius: 0 2px 2px 0;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.selectize-control.plugin-remove_button [data-value] .remove:hover {
  background: rgba(0, 0, 0, 0.05);
}
.selectize-control.plugin-remove_button [data-value].active .remove {
  border-left-color: #00578d;
}
.selectize-control.plugin-remove_button .disabled [data-value] .remove:hover {
  background: none;
}
.selectize-control.plugin-remove_button .disabled [data-value] .remove {
  border-left-color: #aaaaaa;
}
.selectize-control.plugin-remove_button .remove-single {
  position: absolute;
  right: 28px;
  top: 6px;
  font-size: 23px;
}
.selectize-control {
  position: relative;
}
.selectize-dropdown,
.selectize-input,
.selectize-input input {
  color: #303030;
  font-family: inherit;
  font-size: 13px;
  line-height: 18px;
  -webkit-font-smoothing: inherit;
}
.selectize-input,
.selectize-control.single .selectize-input.input-active {
  background: #ffffff;
  cursor: text;
  display: inline-block;
}
.selectize-input {
  border: 1px solid #d0d0d0;
  padding: 8px 8px;
  display: inline-block;
  width: 100%;
  overflow: hidden;
  position: relative;
  z-index: 1;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.1);
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.selectize-control.multi .selectize-input.has-items {
  padding: 5px 8px 2px;
}
.selectize-input.full {
  background-color: #ffffff;
}
.selectize-input.disabled,
.selectize-input.disabled * {
  cursor: default !important;
}
.selectize-input.focus {
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.15);
}
.selectize-input.dropdown-active {
  -webkit-border-radius: 3px 3px 0 0;
  -moz-border-radius: 3px 3px 0 0;
  border-radius: 3px 3px 0 0;
}
.selectize-input > * {
  vertical-align: baseline;
  display: -moz-inline-stack;
  display: inline-block;
  zoom: 1;
  *display: inline;
}
.selectize-control.multi .selectize-input > div {
  cursor: pointer;
  margin: 0 3px 3px 0;
  padding: 2px 6px;
  background: #1da7ee;
  color: #ffffff;
  border: 1px solid #0073bb;
}
.selectize-control.multi .selectize-input > div.active {
  background: #92c836;
  color: #ffffff;
  border: 1px solid #00578d;
}
.selectize-control.multi .selectize-input.disabled > div,
.selectize-control.multi .selectize-input.disabled > div.active {
  color: #ffffff;
  background: #d2d2d2;
  border: 1px solid #aaaaaa;
}
.selectize-input > input {
  display: inline-block !important;
  padding: 0 !important;
  min-height: 0 !important;
  max-height: none !important;
  max-width: 100% !important;
  margin: 0 1px !important;
  text-indent: 0 !important;
  border: 0 none !important;
  background: none !important;
  line-height: inherit !important;
  -webkit-user-select: auto !important;
  -webkit-box-shadow: none !important;
  box-shadow: none !important;
}
.selectize-input > input::-ms-clear {
  display: none;
}
.selectize-input > input:focus {
  outline: none !important;
}
.selectize-input::after {
  content: ' ';
  display: block;
  clear: left;
}
.selectize-input.dropdown-active::before {
  content: ' ';
  display: block;
  position: absolute;
  background: #f0f0f0;
  height: 1px;
  bottom: 0;
  left: 0;
  right: 0;
}
.selectize-dropdown {
  position: absolute;
  z-index: 10;
  border: 1px solid #d0d0d0;
  background: #ffffff;
  margin: -1px 0 0 0;
  border-top: 0 none;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
  -webkit-border-radius: 0 0 3px 3px;
  -moz-border-radius: 0 0 3px 3px;
  border-radius: 0 0 3px 3px;
}
.selectize-dropdown [data-selectable] {
  cursor: pointer;
  overflow: hidden;
}
.selectize-dropdown [data-selectable] .highlight {
  background: rgba(125, 168, 208, 0.2);
  -webkit-border-radius: 1px;
  -moz-border-radius: 1px;
  border-radius: 1px;
}
.selectize-dropdown [data-selectable],
.selectize-dropdown .optgroup-header {
  padding: 5px 8px;
}
.selectize-dropdown .optgroup:first-child .optgroup-header {
  border-top: 0 none;
}
.selectize-dropdown .optgroup-header {
  color: #303030;
  background: #ffffff;
  cursor: default;
}
.selectize-dropdown .active {
  background-color: #f5fafd;
  color: #495c68;
}
.selectize-dropdown .active.create {
  color: #495c68;
}
.selectize-dropdown .create {
  color: rgba(48, 48, 48, 0.5);
}
.selectize-dropdown-content {
  overflow-y: auto;
  overflow-x: hidden;
  max-height: 200px;
  -webkit-overflow-scrolling: touch;
}
.selectize-control.single .selectize-input,
.selectize-control.single .selectize-input input {
  cursor: pointer;
}
.selectize-control.single .selectize-input.input-active,
.selectize-control.single .selectize-input.input-active input {
  cursor: text;
}
.selectize-control.single .selectize-input:after {
  content: ' ';
  display: block;
  position: absolute;
  top: 50%;
  right: 15px;
  margin-top: -3px;
  width: 0;
  height: 0;
  border-style: solid;
  border-width: 5px 5px 0 5px;
  border-color: #808080 transparent transparent transparent;
}
.selectize-control.single .selectize-input.dropdown-active:after {
  margin-top: -4px;
  border-width: 0 5px 5px 5px;
  border-color: transparent transparent #808080 transparent;
}
.selectize-control.rtl.single .selectize-input:after {
  left: 15px;
  right: auto;
}
.selectize-control.rtl .selectize-input > input {
  margin: 0 4px 0 -2px !important;
}
.selectize-control .selectize-input.disabled {
  opacity: 0.5;
  background-color: #fafafa;
}
.selectize-control.multi .selectize-input.has-items {
  padding-left: 5px;
  padding-right: 5px;
}
.selectize-control.multi .selectize-input.disabled [data-value] {
  color: #999;
  text-shadow: none;
  background: none;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.selectize-control.multi .selectize-input.disabled [data-value],
.selectize-control.multi .selectize-input.disabled [data-value] .remove {
  border-color: #e6e6e6;
}
.selectize-control.multi .selectize-input.disabled [data-value] .remove {
  background: none;
}
.selectize-control.multi .selectize-input [data-value] {
  text-shadow: 0 1px 0 rgba(0, 51, 83, 0.3);
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  background-color: #1b9dec;
  background-image: -moz-linear-gradient(top, #1da7ee, #178ee9);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#1da7ee), to(#178ee9));
  background-image: -webkit-linear-gradient(top, #1da7ee, #178ee9);
  background-image: -o-linear-gradient(top, #1da7ee, #178ee9);
  background-image: linear-gradient(to bottom, #1da7ee, #178ee9);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff1da7ee', endColorstr='#ff178ee9', GradientType=0);
  -webkit-box-shadow: 0 1px 0 rgba(0,0,0,0.2),inset 0 1px rgba(255,255,255,0.03);
  box-shadow: 0 1px 0 rgba(0,0,0,0.2),inset 0 1px rgba(255,255,255,0.03);
}
.selectize-control.multi .selectize-input [data-value].active {
  background-color: #0085d4;
  background-image: -moz-linear-gradient(top, #008fd8, #0075cf);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#008fd8), to(#0075cf));
  background-image: -webkit-linear-gradient(top, #008fd8, #0075cf);
  background-image: -o-linear-gradient(top, #008fd8, #0075cf);
  background-image: linear-gradient(to bottom, #008fd8, #0075cf);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff008fd8', endColorstr='#ff0075cf', GradientType=0);
}
.selectize-control.single .selectize-input {
  -webkit-box-shadow: 0 1px 0 rgba(0,0,0,0.05), inset 0 1px 0 rgba(255,255,255,0.8);
  box-shadow: 0 1px 0 rgba(0,0,0,0.05), inset 0 1px 0 rgba(255,255,255,0.8);
  background-color: #f9f9f9;
  background-image: -moz-linear-gradient(top, #fefefe, #f2f2f2);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fefefe), to(#f2f2f2));
  background-image: -webkit-linear-gradient(top, #fefefe, #f2f2f2);
  background-image: -o-linear-gradient(top, #fefefe, #f2f2f2);
  background-image: linear-gradient(to bottom, #fefefe, #f2f2f2);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fffefefe', endColorstr='#fff2f2f2', GradientType=0);
}
.selectize-control.single .selectize-input,
.selectize-dropdown.single {
  border-color: #b8b8b8;
}
.selectize-dropdown .optgroup-header {
  padding-top: 7px;
  font-weight: bold;
  font-size: 0.85em;
}
.selectize-dropdown .optgroup {
  border-top: 1px solid #f0f0f0;
}
.selectize-dropdown .optgroup:first-child {
  border-top: 0 none;
}
.ui-timepicker-div .ui-widget-header { margin-bottom: 8px; }
.ui-timepicker-div dl { text-align: left; }
.ui-timepicker-div dl dt { float: left; clear:left; padding: 0 0 0 5px; }
.ui-timepicker-div dl dd { margin: 0 10px 10px 40%; }
.ui-timepicker-div td { font-size: 90%; }
.ui-tpicker-grid-label { background: none; border: none; margin: 0; padding: 0; }
.ui-timepicker-div .ui_tpicker_unit_hide{ display: none; }

.ui-timepicker-div .ui_tpicker_time .ui_tpicker_time_input { background: none; color: inherit; border: none; outline: none; border-bottom: solid 1px #555; width: 95%; }
.ui-timepicker-div .ui_tpicker_time .ui_tpicker_time_input:focus { border-bottom-color: #aaa; }

.ui-timepicker-rtl{ direction: rtl; }
.ui-timepicker-rtl dl { text-align: right; padding: 0 5px 0 0; }
.ui-timepicker-rtl dl dt{ float: right; clear: right; }
.ui-timepicker-rtl dl dd { margin: 0 40% 10px 10px; }

/* Shortened version style */
.ui-timepicker-div.ui-timepicker-oneLine { padding-right: 2px; }
.ui-timepicker-div.ui-timepicker-oneLine .ui_tpicker_time, 
.ui-timepicker-div.ui-timepicker-oneLine dt { display: none; }
.ui-timepicker-div.ui-timepicker-oneLine .ui_tpicker_time_label { display: block; padding-top: 2px; }
.ui-timepicker-div.ui-timepicker-oneLine dl { text-align: right; }
.ui-timepicker-div.ui-timepicker-oneLine dl dd, 
.ui-timepicker-div.ui-timepicker-oneLine dl dd > div { display:inline-block; margin:0; }
.ui-timepicker-div.ui-timepicker-oneLine dl dd.ui_tpicker_minute:before,
.ui-timepicker-div.ui-timepicker-oneLine dl dd.ui_tpicker_second:before { content:':'; display:inline-block; }
.ui-timepicker-div.ui-timepicker-oneLine dl dd.ui_tpicker_millisec:before,
.ui-timepicker-div.ui-timepicker-oneLine dl dd.ui_tpicker_microsec:before { content:'.'; display:inline-block; }
.ui-timepicker-div.ui-timepicker-oneLine .ui_tpicker_unit_hide,
.ui-timepicker-div.ui-timepicker-oneLine .ui_tpicker_unit_hide:before{ display: none; }@charset "UTF-8";
* {
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline;
  -webkit-box-sizing: border-box;
          box-sizing: border-box; }

article, aside, details,
summary, figcaption, figure,
footer, header, hgroup,
menu, nav, section {
  display: block; }

body {
  line-height: 1; }

ol, ul {
  list-style: none; }

blockquote, q {
  quotes: none; }

blockquote:before, blockquote:after,
q:before, q:after {
  content: '';
  content: none; }

table {
  border-collapse: collapse;
  border-spacing: 0; }

body {
  font-family: "Open Sans", sans-serif;
  color: #191919;
  background-color: #eee;
  font-size: 14px; }

a {
  text-decoration: none;
  color: #666; }
  a:hover {
    color: #f00; }

p {
  margin-bottom: 10px; }

h2,
.heading-large {
  font-family: "Raleway", sans-serif;
  font-weight: 300;
  color: #191919;
  font-size: 32px;
  margin-bottom: 40px; }

h3,
.heading-medium {
  font-family: "Raleway", sans-serif;
  font-weight: 400;
  color: #191919;
  font-size: 18px;
  margin-bottom: 10px; }

h4,
.heading-small {
  font-family: "Raleway", sans-serif;
  font-weight: 600;
  color: #191919;
  font-size: 15px;
  margin-bottom: 10px; }

.text-default {
  font-family: "Open Sans", sans-serif;
  font-size: 14px; }

.text-cta {
  font-family: "Open Sans", sans-serif;
  font-weight: 600;
  font-size: 14px; }

.text-description {
  font-family: "Open Sans", sans-serif;
  font-size: 12px; }

.text-meta {
  font-family: "Open Sans", sans-serif;
  font-size: 10px; }

header {
  margin-bottom: 40px; }
  header h2,
  header h3,
  header h4 {
    margin-bottom: 10px; }

#container {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-flow: column;
          flex-flow: column;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: start;
      -ms-flex-pack: start;
          justify-content: flex-start;
  width: 100%; }

#content {
  position: relative; }

.main {
  -webkit-box-shadow: 0px 10px 40px -10px #c4c4c4;
          box-shadow: 0px 10px 40px -10px #c4c4c4;
  background-color: #fff;
  padding: 30px;
  margin: 0 30px;
  position: relative;
  width: 100%;
  max-width: 1400px;
  min-height: 250px;
  z-index: 1; }
  .main:before, .main:after {
    content: "";
    display: table; }
  .main:after {
    clear: both; }

.width-wrapper {
  max-width: 1400px;
  margin: 0 auto; }
  .width-wrapper:before, .width-wrapper:after {
    content: "";
    display: table; }
  .width-wrapper:after {
    clear: both; }

.draggable {
  position: relative;
  padding: 10px 0;
  background-color: #fff;
  -webkit-transition: -webkit-box-shadow 200ms;
  transition: -webkit-box-shadow 200ms;
  transition: box-shadow 200ms;
  transition: box-shadow 200ms, -webkit-box-shadow 200ms; }
  .draggable:before {
    cursor: move;
    content: "";
    background-color: #c0c0c0;
    display: block;
    width: 13px;
    height: calc(100% + 2px);
    position: absolute;
    top: -1px;
    left: -6px;
    -webkit-transition: background-color 100ms;
    transition: background-color 100ms; }
  .draggable:after {
    cursor: move;
    text-shadow: #191919 0px 1px 1px;
    content: "\250B";
    color: #eee;
    font-size: 24px;
    position: relative;
    top: 10px;
    left: -2.65rem;
    -webkit-transform: translateY(-50%);
            transform: translateY(-50%); }
  .draggable:active {
    -webkit-box-shadow: 0px 10px 40px -10px #c4c4c4;
            box-shadow: 0px 10px 40px -10px #c4c4c4; }
  .draggable:hover:before {
    background-color: #b8b8b8; }

svg {
  width: 100%; }
  svg .bar {
    fill: #f00; }
  svg .type {
    fill: #000; }

polygon.bar {
  fill: #f00; }

.actions__action {
  display: inline-block;
  width: 12px;
  height: 12px;
  margin-right: 20px; }
  .actions__action .fa {
    line-height: 0;
    color: #191919; }
  .actions__action:last-of-type {
    margin-right: 0; }
  .actions__action:hover .fa {
    color: #f00; }

.actions__help {
  font-size: 12px;
  margin-top: 8px; }

.asset {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-flex: 1;
      -ms-flex: 1;
          flex: 1; }
  .asset:before, .asset:after {
    content: "";
    display: table; }
  .asset:after {
    clear: both; }

.asset__preview {
  border: 1px dashed #191919;
  border-radius: 3px;
  background-size: 92%;
  background-repeat: no-repeat;
  background-position: 4px 4px;
  -webkit-box-flex: 0;
      -ms-flex-positive: 0;
          flex-grow: 0;
  margin: 0 10px 10px 0;
  width: 100px;
  height: 100px; }

.asset__actions {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1; }

.asset__edit-link {
  margin-left: 10px; }

.asset__buttons {
  width: 100%;
  padding-top: 10px; }

.asset__select,
.asset__crop-item {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-flex: 1;
      -ms-flex: 1;
          flex: 1; }

.asset__select {
  margin-bottom: 10px;
  position: relative; }
  .asset__select input {
    position: absolute; }
  .asset__select .selectize-control {
    -webkit-box-flex: 1;
        -ms-flex: 1;
            flex: 1;
    margin-right: 10px; }

.asset__add-link {
  -webkit-box-flex: 0;
      -ms-flex: 0;
          flex: 0; }

.asset__crop-item {
  margin-bottom: 10px; }

.asset__crop-label {
  display: block;
  border: #eee 1px solid;
  padding: 6px;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1; }

.asset__crop-link {
  -webkit-box-flex: 0;
      -ms-flex-positive: 0;
          flex-grow: 0;
  color: #191919;
  background-color: #eee;
  margin-right: 160px;
  font-weight: bold; }
  .asset__crop-link:hover {
    color: #191919;
    background-color: #b8b8b8; }

.asset__tags {
  margin-top: 10px; }

.tabs {
  margin: 0 0 0 10px;
  padding: 0;
  white-space: nowrap;
  overflow: auto;
  border-bottom: 1px solid #eee; }
  .tabs:before, .tabs:after {
    content: "";
    display: table; }
  .tabs:after {
    clear: both; }
  .tabs > li {
    display: inline-block;
    margin-right: 10px; }
  .tabs .button {
    color: #fff;
    background-color: #b8b8b8; }
    .tabs .button.active, .tabs .button:hover {
      color: #fff;
      background-color: #0084ff; }

.sub-tabs {
  margin: 0 0 40px;
  padding: 0;
  border-bottom: none; }
  .sub-tabs > li {
    display: inline-block;
    margin-right: 10px; }
    .sub-tabs > li:not(:last-of-type) {
      position: relative;
      padding-right: 10px;
      margin-right: 10px; }
      .sub-tabs > li:not(:last-of-type):after {
        content: '';
        display: inline-block;
        background-color: #191919;
        width: 1px;
        height: 30px;
        top: 50%;
        right: 0;
        position: absolute;
        -webkit-transform: translateY(-50%);
                transform: translateY(-50%); }
  .sub-tabs a {
    display: block;
    padding: 10px; }
    .sub-tabs a.active {
      color: #fff;
      background-color: #b8b8b8; }

table {
  border-bottom: 1px solid #eee;
  background-color: #fff;
  width: 100%; }
  table th,
  table td {
    padding: 10px;
    vertical-align: top; }
    table th:first-of-type:not(:only-child),
    table td:first-of-type:not(:only-child) {
      padding-left: 70px; }
    table th:last-of-type:not(:only-child),
    table td:last-of-type:not(:only-child) {
      padding-right: 70px; }
    table th.checkbox,
    table td.checkbox {
      width: 70px;
      padding: 10px !important;
      text-align: center; }
  table caption {
    background-color: #fff;
    text-align: left;
    text-transform: capitalize;
    font-size: 32px; }
  table thead {
    border-bottom: 1px solid #eee; }
  table th {
    text-transform: uppercase;
    text-align: left; }
    table th a {
      color: #191919; }
    table th.sortable .fa {
      margin-left: 10px; }
  table tbody[draggable=true] tr:hover td {
    background-color: #eee; }
  table tbody tr:hover {
    background-color: #eee; }
  table.is-empty,
  table.is-empty thead {
    border: none; }

input[type=text],
input[type=file],
input[type=password],
input[type=number],
input[type=url],
input[type=email],
textarea {
  background-color: #eee;
  display: block;
  width: 100%; }
  td input[type=text], td
  input[type=file], td
  input[type=password], td
  input[type=number], td
  input[type=url], td
  input[type=email], td
  textarea {
    display: inline-block;
    width: auto; }

input[type=text],
input[type=file],
input[type=password],
input[type=number],
input[type=url],
input[type=email] {
  line-height: 38px;
  text-indent: 10px;
  margin-top: 10px; }

input[type=number] {
  -moz-appearance: textfield;
  -webkit-appearance: textfield;
  appearance: textfield; }

input[type=file] {
  padding: 12px;
  line-height: 1;
  text-indent: 0;
  outline: none; }

input[type=radio] {
  display: none; }
  input[type=radio] + label {
    position: relative;
    padding-left: 30px;
    color: #191919;
    font-weight: 200;
    font-size: 16px;
    margin-top: 3px; }
  input[type=radio] + label:before {
    position: absolute;
    top: 0;
    left: 0;
    content: '';
    border-radius: 50%;
    border: 2px solid #191919;
    width: 14px;
    height: 14px;
    margin-right: 30px; }
  input[type=radio]:checked + label:after {
    position: absolute;
    top: 0;
    left: 0;
    content: '';
    width: 18px;
    height: 18px;
    background-color: #0084ff;
    border-radius: 50%;
    margin-right: 30px; }

input[type=checkbox] {
  position: relative; }
  input[type=checkbox]:after {
    content: '';
    position: absolute;
    top: 50%;
    left: 50%;
    width: 70px;
    height: 35px;
    background: rgba(255, 0, 255, 0);
    -webkit-transform: translate(-50%, -50%);
            transform: translate(-50%, -50%); }

legend {
  font-family: "Raleway", sans-serif;
  font-weight: 300;
  color: #191919;
  font-size: 32px;
  margin-bottom: 40px; }

label {
  color: #666;
  font-size: 18px;
  font-weight: normal;
  display: block;
  margin-bottom: 15px; }
  label.required {
    position: relative;
    padding-left: 11px; }
    label.required:before {
      content: '*';
      position: absolute;
      left: 0;
      top: 0;
      font-weight: bold; }

fieldset:not(:last-of-type),
fieldset > div:not(:last-of-type) {
  margin-bottom: 40px; }

.field-row {
  margin-bottom: 25px; }
  .field-row em {
    margin-bottom: 10px;
    display: inline-block;
    width: 100%; }

.object-name {
  font-weight: bold; }

.errorlist {
  margin: -15px 0 25px;
  padding: 0; }
  .errorlist li {
    color: #f00; }

.errornote {
  color: #f00; }

.messagelist {
  font-family: "Raleway", sans-serif;
  font-weight: 400;
  color: #191919;
  font-size: 18px;
  margin-bottom: 10px;
  color: #0084ff;
  margin-bottom: 20px; }

button,
.button {
  display: inline-block;
  cursor: pointer;
  min-width: 150px;
  line-height: 40px;
  text-align: center;
  font-size: 14px;
  -webkit-transition: background-color 200ms;
  transition: background-color 200ms; }
  button .fa,
  .button .fa {
    margin-right: 4px; }
  button--primary,
  .button--primary {
    color: #fff;
    background-color: #0084ff;
    padding: 0 15px; }
    button--primary.active, button--primary:hover,
    .button--primary.active,
    .button--primary:hover {
      color: #fff;
      background-color: #006bcd; }
  button--secondary,
  .button--secondary {
    color: #fff;
    background-color: #b8b8b8; }
    button--secondary.active, button--secondary:hover,
    .button--secondary.active,
    .button--secondary:hover {
      color: #fff;
      background-color: #666; }
  button--tertiary,
  .button--tertiary {
    color: #fff;
    background-color: #e31b23; }
    button--tertiary.active, button--tertiary:hover,
    .button--tertiary.active,
    .button--tertiary:hover {
      color: #fff;
      background-color: #a7161b; }
  button--disabled,
  .button--disabled {
    color: #fff;
    cursor: default;
    background-color: #eee; }
    button--disabled:hover,
    .button--disabled:hover {
      color: #fff;
      background-color: #eee; }
  button:focus,
  .button:focus {
    outline: none; }

.button-group:before, .button-group:after {
  content: "";
  display: table; }

.button-group:after {
  clear: both; }

.button-group .button:not(:last-child) {
  margin-right: 10px; }

.button-group .divider {
  float: left; }
  .button-group .divider:not(:last-child) {
    position: relative;
    padding-right: 20px;
    margin-right: 20px; }
    .button-group .divider:not(:last-child):after {
      content: '';
      display: inline-block;
      background-color: #b8b8b8;
      width: 1px;
      height: 38px;
      top: 50%;
      right: 0;
      position: absolute;
      -webkit-transform: translateY(-50%);
              transform: translateY(-50%); }

.button-group--actions {
  padding-bottom: 20px;
  border-bottom: #eee 1px solid; }

.button-group--submit {
  padding-top: 40px;
  border-top: #eee 1px solid;
  margin-top: 50px;
  text-align: right; }

.button-group .button_inner-container {
  position: relative;
  display: inline-block; }
  .button-group .button_inner-container .button__loading-overlay {
    position: absolute;
    top: 0;
    right: 10px;
    opacity: 0.8;
    z-index: 1;
    content: "";
    background: #666;
    height: 100%;
    width: 150px;
    display: none; }
    .button-group .button_inner-container .button__loading-overlay--active {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex; }

.lds-ring {
  display: inline-block;
  position: relative;
  width: 40px;
  height: 40px;
  margin: auto; }
  .lds-ring div {
    -webkit-box-sizing: border-box;
            box-sizing: border-box;
    display: block;
    position: absolute;
    width: 30px;
    height: 30px;
    margin: 5px;
    border: 5px solid #fff;
    border-radius: 50%;
    -webkit-animation: lds-ring 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;
            animation: lds-ring 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;
    border-color: #fff transparent transparent transparent; }
    .lds-ring div:nth-child(1) {
      -webkit-animation-delay: -0.45s;
              animation-delay: -0.45s; }
    .lds-ring div:nth-child(2) {
      -webkit-animation-delay: -0.3s;
              animation-delay: -0.3s; }
    .lds-ring div:nth-child(3) {
      -webkit-animation-delay: -0.15s;
              animation-delay: -0.15s; }

@-webkit-keyframes lds-ring {
  0% {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg); }
  100% {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg); } }

@keyframes lds-ring {
  0% {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg); }
  100% {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg); } }

.filters {
  position: relative;
  width: 30%;
  float: right;
  text-align: right; }
  .filters .fa-angle-down {
    color: #b8b8b8;
    -webkit-transition: -webkit-transform 150ms;
    transition: -webkit-transform 150ms;
    transition: transform 150ms;
    transition: transform 150ms, -webkit-transform 150ms; }
  .filters:hover .fa-angle-down {
    color: #f00;
    -webkit-transform: scaleY(-1);
            transform: scaleY(-1); }
  .filters .button-group {
    margin-top: 20px;
    padding-top: 20px; }

.filters__label {
  display: inline-block;
  margin-right: 10px;
  text-transform: uppercase; }

.filters__form {
  -webkit-box-shadow: 0px 10px 40px -10px #c4c4c4;
          box-shadow: 0px 10px 40px -10px #c4c4c4;
  padding-top: 5px;
  position: absolute;
  top: 0;
  width: 100%;
  opacity: 0;
  z-index: -1;
  -webkit-transition: top 250ms, opacity 200ms 50ms;
  transition: top 250ms, opacity 200ms 50ms;
  background-color: #fff;
  padding: 20px;
  text-align: left; }
  .filters:hover .filters__form {
    top: 100%;
    opacity: 1;
    z-index: 1;
    pointer-events: auto;
    -webkit-transition: top 250ms, opacity 200ms 50ms;
    transition: top 250ms, opacity 200ms 50ms; }
  .filters__form label:not(first-of-type) {
    margin-top: 20px; }

.header-main {
  border-bottom: 1px solid #fff;
  padding: 45px 30px 0;
  width: 100%; }

.header-main__logo {
  width: 190px;
  height: 40px;
  float: left;
  font-family: "Raleway", sans-serif;
  font-weight: 300;
  color: #191919;
  font-size: 32px;
  margin-bottom: 40px; }
  .header-main__logo a {
    cursor: pointer;
    display: block;
    height: 100%; }

.nav-account {
  float: right;
  text-transform: uppercase;
  text-align: right; }
  .nav-account p {
    margin-bottom: 10px;
    font-family: "Raleway", sans-serif;
    font-size: 15px; }
  .nav-account strong {
    font-weight: bold; }
  .nav-account a {
    color: #000;
    font-size: 12px; }
    .nav-account a:hover {
      color: #f00; }
    .nav-account a:not(:last-of-type) {
      position: relative;
      padding-right: 10px;
      margin-right: 10px; }
      .nav-account a:not(:last-of-type):after {
        content: '';
        display: inline-block;
        background-color: #191919;
        width: 1px;
        height: 10px;
        top: 50%;
        right: 0;
        position: absolute;
        -webkit-transform: translateY(-50%);
                transform: translateY(-50%); }

.user-nav {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row; }

.header-object {
  width: 100%;
  max-width: 1400px;
  margin: 0 30px 30px;
  position: relative;
  padding: 40px 30px 0;
  z-index: 2; }
  .header-object:before, .header-object:after {
    content: "";
    display: table; }
  .header-object:after {
    clear: both; }

.header-object__breadcrumb {
  font-family: "Open Sans", sans-serif;
  color: #666;
  font-size: 18px;
  position: absolute;
  left: 30px;
  top: 0;
  font-size: 15px; }
  .header-object__breadcrumb i {
    color: #f00;
    margin-right: 6px; }

.header-object__title {
  font-size: 32px;
  color: #191919;
  float: left; }

.header-object__tools {
  float: right;
  text-transform: uppercase;
  text-align: right;
  font-size: 12px; }
  .header-object__tools p {
    color: #666;
    margin-bottom: 15px; }
    .header-object__tools p span {
      position: relative;
      padding-right: 10px;
      margin-right: 10px; }
      .header-object__tools p span:after {
        content: '';
        display: inline-block;
        background-color: #666;
        width: 1px;
        height: 9px;
        top: 50%;
        right: 0;
        position: absolute;
        -webkit-transform: translateY(-50%);
                transform: translateY(-50%); }
  .header-object__tools a {
    color: #191919; }
    .header-object__tools a:not(:last-of-type) {
      position: relative;
      padding-right: 10px;
      margin-right: 10px; }
      .header-object__tools a:not(:last-of-type):after {
        content: '';
        display: inline-block;
        background-color: #191919;
        width: 1px;
        height: 9px;
        top: 50%;
        right: 0;
        position: absolute;
        -webkit-transform: translateY(-50%);
                transform: translateY(-50%); }

.header-object__actions {
  float: left;
  position: relative; }
  .header-object__actions .fa-chevron-down {
    color: #b8b8b8;
    -webkit-transition: -webkit-transform 150ms;
    transition: -webkit-transform 150ms;
    transition: transform 150ms;
    transition: transform 150ms, -webkit-transform 150ms; }
  .header-object__actions:hover .fa-chevron-down {
    color: #f00;
    -webkit-transform: scaleY(-1);
            transform: scaleY(-1); }
  .header-object__actions .fa {
    margin: 7px 0 0 9px; }

.header-object__actions-list {
  margin-left: 7px; }
  .header-object__actions-list:not(:empty) {
    -webkit-box-shadow: 0px 10px 40px -10px #c4c4c4;
            box-shadow: 0px 10px 40px -10px #c4c4c4;
    padding-top: 5px;
    position: absolute;
    top: 0;
    width: 100%;
    opacity: 0;
    z-index: -1;
    -webkit-transition: top 250ms, opacity 200ms 50ms;
    transition: top 250ms, opacity 200ms 50ms;
    width: auto; }
    .header-object__actions:hover .header-object__actions-list:not(:empty) {
      top: 100%;
      opacity: 1;
      z-index: 1;
      pointer-events: auto;
      -webkit-transition: top 250ms, opacity 200ms 50ms;
      transition: top 250ms, opacity 200ms 50ms; }
  .header-object__actions-list:empty {
    background-color: #eee;
    position: absolute;
    opacity: 1;
    z-index: 1;
    width: 20px;
    height: 20px;
    left: 0px;
    top: 8px; }
  .header-object__actions-list a {
    display: block;
    background-color: #fff;
    padding: 15px 15px 10px;
    white-space: nowrap; }
    .header-object__actions-list a:last-child {
      padding-bottom: 15px; }

.pagination {
  background-color: #fff;
  padding: 20px 0;
  text-align: center; }

.pagination__links {
  text-transform: uppercase; }

.pagination__current-page {
  margin: 0 8px; }
  .pagination__current-page:first-child {
    margin-left: 0; }

.pagination__previous,
.pagination__next {
  display: inline-block;
  background-color: #0084ff;
  width: 30px;
  height: 30px;
  text-align: center;
  line-height: 30px; }
  .pagination__previous i,
  .pagination__next i {
    color: #fff; }

.nav-sidebar {
  float: left;
  width: 20%; }

.nav-sidebar + .content {
  float: right;
  width: 79%;
  padding-left: 20px; }
  .nav-sidebar + .content:before {
    content: '';
    width: 1px;
    background-color: #eee;
    position: absolute;
    height: 100%;
    margin-left: -30px; }

.nav-sidebar__link {
  color: #191919;
  display: block;
  padding: 12px 0 12px 15px;
  text-transform: uppercase; }
  .nav-sidebar__link:active {
    color: #fff;
    background-color: #f00; }

.nav-dashboard {
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row;
  width: 100%;
  max-width: 1120px;
  margin-bottom: 45px; }

.nav-dashboard__list {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-flex: 1;
      -ms-flex: 1;
          flex: 1; }

.nav-dashboard__item {
  margin: 0 1.25% 1% 0;
  min-width: 19%; }
  .nav-dashboard__item:nth-child(1):last-child {
    width: 25%; }
  .nav-dashboard__item:nth-child(1):nth-last-child(2), .nav-dashboard__item:nth-child(2):last-child, .nav-dashboard__item:nth-child(1):nth-last-child(3), .nav-dashboard__item:nth-child(2):nth-last-child(2), .nav-dashboard__item:nth-child(3):last-child, .nav-dashboard__item:nth-child(1):nth-last-child(4), .nav-dashboard__item:nth-child(2):nth-last-child(3), .nav-dashboard__item:nth-child(3):nth-last-child(2), .nav-dashboard__item:nth-child(4):last-child {
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1; }
  .nav-dashboard__item:nth-child(5n), .nav-dashboard__item:last-child {
    margin-right: 0; }

.nav-dashboard__sublist {
  background-color: #fff; }

.nav-dashboard__sublist-item {
  border-top: 1px solid #eee;
  padding: 20px 0;
  text-align: center; }

.nav-dashboard__item-title {
  background-color: #fff;
  display: block;
  padding: 20px 0;
  text-align: center; }
  .nav-dashboard__item-title .fa {
    display: block;
    height: 45px;
    font-size: 35px; }

.nav-main {
  -webkit-box-shadow: 0px 10px 40px -10px #c4c4c4;
          box-shadow: 0px 10px 40px -10px #c4c4c4;
  background-color: #fff;
  margin-bottom: 25px;
  position: relative;
  z-index: 0;
  width: 100%;
  -webkit-transition: z-index 0ms 250ms;
  transition: z-index 0ms 250ms; }
  .nav-main:hover {
    z-index: 3;
    -webkit-transition: z-index 0ms 0ms;
    transition: z-index 0ms 0ms; }

.nav-main__list {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  margin: auto;
  max-width: 1400px;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row; }

.nav-main__item {
  display: inline-block;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  position: relative; }
  .nav-main__item .fa-angle-down {
    color: #b8b8b8;
    -webkit-transition: -webkit-transform 150ms;
    transition: -webkit-transform 150ms;
    transition: transform 150ms;
    transition: transform 150ms, -webkit-transform 150ms; }
  .nav-main__item:hover .fa-angle-down {
    color: #f00;
    -webkit-transform: scaleY(-1);
            transform: scaleY(-1); }
  .nav-main__item .fa-angle-down {
    font-weight: bold;
    margin-left: 5px; }
  .nav-main__item:hover .nav-main__item-title {
    color: #f00; }

.nav-main__item-title {
  background-color: #fff;
  display: block;
  height: 60px;
  line-height: 60px;
  text-align: center;
  text-transform: uppercase;
  overflow: hidden; }
  .nav-main__item-title span {
    position: relative; }
    .nav-main__item:active .nav-main__item-title span:before {
      top: 34px; }

.nav-main__sublist {
  -webkit-box-shadow: 0px 10px 40px -10px #c4c4c4;
          box-shadow: 0px 10px 40px -10px #c4c4c4;
  padding-top: 5px;
  position: absolute;
  top: 0;
  width: 100%;
  opacity: 0;
  z-index: -1;
  -webkit-transition: top 250ms, opacity 200ms 50ms;
  transition: top 250ms, opacity 200ms 50ms;
  left: -8px;
  pointer-events: none; }
  .nav-main__item:hover .nav-main__sublist {
    top: 100%;
    opacity: 1;
    z-index: 1;
    pointer-events: auto;
    -webkit-transition: top 250ms, opacity 200ms 50ms;
    transition: top 250ms, opacity 200ms 50ms; }
  .nav-main__sublist:before {
    display: block;
    text-align: center;
    color: #fff;
    font-size: 40px;
    line-height: 12px; }

.nav-main__sublist-item {
  background-color: #fff;
  padding: 10px;
  text-align: center;
  font-family: "Open Sans", sans-serif;
  font-weight: 600;
  font-size: 14px;
  text-transform: uppercase; }
  .nav-main__sublist-item:first-child {
    padding-top: 20px; }
  .nav-main__sublist-item:last-child {
    padding-bottom: 20px; }

.nav-main__sublist-link {
  display: block;
  color: #666;
  cursor: pointer; }
  .nav-main__sublist-link:active, .nav-main__sublist-link:hover {
    color: #f00; }

.footer-main {
  max-width: 1400px;
  margin: 0 auto;
  padding: 50px 60px; }
  .footer-main:before, .footer-main:after {
    content: "";
    display: table; }
  .footer-main:after {
    clear: both; }

.footer-main__logo {
  font-family: "Open Sans", sans-serif;
  font-size: 12px;
  float: left;
  width: 100%; }
  .footer-main__logo p:last-of-type {
    float: right;
    text-align: right; }
  .footer-main__logo strong {
    display: block;
    margin-bottom: 5px; }
  .footer-main__logo a {
    display: block;
    margin-bottom: 5px; }

.footer-main__logo--red a {
  width: 141px;
  height: 31px;
  float: right; }

.footer-main__logo--red strong {
  text-align: right; }

.footer-main__logo--scarlet a {
  width: 166px;
  height: 33px; }

.footer-main__logo--scarlet strong {
  text-indent: 40px; }

.dashboard-history caption {
  margin-bottom: 30px;
  font-family: "Raleway", sans-serif;
  font-weight: 300;
  color: #191919;
  font-size: 32px;
  margin-bottom: 40px; }

.dashboard-history thead tr:nth-child(2)
th:nth-child(1) {
  width: 8%;
  padding-left: 0;
  text-align: center; }

.dashboard-history th:nth-child(2) {
  width: 18%;
  min-width: 190px; }

.dashboard-history th:nth-child(3) {
  width: 14%; }

.dashboard-history th:nth-child(4) {
  width: 49%; }

.dashboard-history th:nth-child(5) {
  width: 11%; }

.dashboard-history td:first-of-type:not(:only-child) {
  padding-left: 40px; }

.dashboard-history__filter {
  position: absolute;
  right: 20px;
  top: 20px; }
  .dashboard-history__filter:before, .dashboard-history__filter:after {
    content: "";
    display: table; }
  .dashboard-history__filter:after {
    clear: both; }
  .dashboard-history__filter label,
  .dashboard-history__filter .button {
    display: none; }

.widget-asset br {
  height: 10px; }

.widget-asset-preview {
  width: 100px;
  height: 100px; }

.widget-asset-simple-preview {
  height: 100px;
  width: 100px;
  display: block;
  margin-bottom: 10px; }

.login {
  background-color: #191919;
  height: 100vh;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-flow: column;
          flex-flow: column;
  font-family: "Raleway", sans-serif;
  position: relative; }
  .login strong {
    color: #eee;
    font-size: 9px; }
  .login label {
    color: #b8b8b8;
    font-size: 18px;
    font-weight: 300;
    margin-bottom: 10px; }
  .login svg {
    color: #fff;
    height: 20px; }
    .login svg .bar {
      fill: #f00; }
    .login svg .type {
      stroke: #eee; }
  .login__logo--main {
    width: 200px;
    margin-bottom: 80px; }
  .login__form {
    width: 255px; }
  .login .button-group--submit {
    border-top: none;
    margin: 0 auto;
    text-align: center;
    padding-top: 5px; }
  .login__footer {
    position: absolute;
    bottom: 0; }
  .login .footer-main__logo--scarlet strong {
    text-indent: 61px; }
  .login .footer-main__logo--red strong {
    text-indent: 45px;
    text-align: center; }

.crop-list__name {
  display: block; }

.crop-list__dimensions {
  color: #b8b8b8;
  font-size: 12px;
  display: block; }

.crop-info strong {
  font-weight: 700; }

.color--red {
  color: #e31b23; }

.color--blue {
  color: #0084ff; }

.apply-crop {
  display: block;
  float: left;
  opacity: 1;
  max-height: none;
  overflow: visible;
  position: relative; }
  .apply-crop--hidden {
    overflow: hidden;
    opacity: 0;
    max-height: 0; }
  .apply-crop .check {
    position: absolute;
    left: 100%;
    height: 40px;
    width: 40px;
    opacity: 0;
    -webkit-transition: 0.5s opacity ease;
    transition: 0.5s opacity ease; }
  .apply-crop.clicked .check {
    opacity: 1; }

.preview-image {
  display: block;
  float: left;
  clear: left;
  margin-top: 20px; }

.apply-crop--hidden ~ .preview-image {
  display: none; }

.wysihtml5-sandbox {
  color: #0084ff;
  font-size: 18px;
  outline: 0;
  width: 100%;
  background: #fff;
  height: 400px;
  margin-bottom: 20px;
  display: block; }

.editor__content {
  position: relative; }

.editor__textarea {
  background-color: #eee;
  padding: 10px; }
  .editor__textarea body {
    font-size: 22px;
    font-family: AvenirRoman;
    color: #0084ff;
    line-height: 1.2; }
  .editor__textarea h1 {
    font-size: 48px; }
  .editor__textarea h2 {
    font-size: 39px; }
  .editor__textarea h3 {
    font-size: 31px; }
  .editor__textarea h4 {
    font-size: 25px; }
  .editor__textarea h1,
  .editor__textarea h2,
  .editor__textarea h3,
  .editor__textarea h4 {
    line-height: 1.2em;
    margin-bottom: 1.1em; }
  .editor__textarea p,
  .editor__textarea li {
    line-height: 1.6em;
    margin-bottom: 1.4em; }
  .editor__textarea ul {
    padding-left: 40px;
    list-style: disc; }
    .editor__textarea ul ul {
      list-style: circle; }
  .editor__textarea ol {
    padding-left: 40px;
    list-style: decimal; }
    .editor__textarea ol ol {
      list-style: lower-alpha; }
  .editor__textarea ol ol,
  .editor__textarea ol ul,
  .editor__textarea ul ol,
  .editor__textarea ul ul {
    padding-bottom: 0; }
  .editor__textarea b,
  .editor__textarea strong {
    font-weight: bold; }
  .editor__textarea i,
  .editor__textarea em {
    font-style: italic; }
  .editor__textarea a {
    cursor: pointer;
    color: #0084ff; }
    .editor__textarea a:hover {
      text-decoration: underline; }
    .editor__textarea a:visited {
      color: #8197a3; }
  .editor__textarea .text--annotated,
  .editor__textarea a.text--annotated {
    background: #b6cad1;
    color: #fff;
    text-decoration: none;
    padding: 1px 3px; }
    .editor__textarea .text--annotated:after,
    .editor__textarea a.text--annotated:after {
      content: ' *';
      font-weight: normal; }

.editor__toolbar {
  border: 1px solid #eee;
  position: relative;
  border-bottom: none;
  padding: 10px; }
  .editor__toolbar + textarea {
    height: 400px;
    display: block;
    font: 14px/1 Consolas, "Lucida Console", Monaco, monospace; }

.wysihtml-command-active {
  background: #eee; }

.editor__buttons:before, .editor__buttons:after {
  content: "";
  display: table; }

.editor__buttons:after {
  clear: both; }

.editor__buttons a {
  color: #191919;
  display: block;
  float: left;
  text-align: center;
  padding: 7px 10px;
  text-transform: uppercase;
  min-width: 20px; }
  .editor__buttons a sup {
    font-size: 13px; }
  .editor__buttons a:hover {
    background-color: #eee; }
  .editor__buttons a.wysihtml5-action-active, .editor__buttons a.wysihtml5-command-active {
    background-color: #0084ff;
    color: #fff; }
  .editor__buttons a + a {
    border-left-width: 0; }

.editor__buttons .spacer {
  margin-right: 20px; }

.editor__buttons .disabled,
.editor__buttons .disabled:hover {
  background-color: #fff;
  cursor: default;
  color: #eee; }

.editor__modal {
  -webkit-box-shadow: 0px 10px 40px -10px #c4c4c4;
          box-shadow: 0px 10px 40px -10px #c4c4c4;
  position: absolute;
  top: 100%;
  left: 50%;
  margin-top: 12px;
  background: #fff;
  border: 1px solid #eee;
  padding: 20px;
  width: 400px;
  margin-left: -200px;
  z-index: 1; }
  .editor__modal textarea {
    padding: 10px;
    height: 70px; }
  .editor__modal .button-group {
    padding-top: 20px;
    margin-top: 30px; }

.editor__annotations {
  visibility: hidden;
  position: absolute;
  width: 0;
  height: 0; }

.wysihtml-sandbox {
  height: 400px;
  width: 100%; }

.formset__forms.ui-sortable .formset__form {
  background: white; }

.formset__form {
  margin-bottom: 40px;
  opacity: 1;
  -webkit-transition: opacity 200ms, position 300ms 350ms, -webkit-transform 300ms;
  transition: opacity 200ms, position 300ms 350ms, -webkit-transform 300ms;
  transition: opacity 200ms, transform 300ms, position 300ms 350ms;
  transition: opacity 200ms, transform 300ms, position 300ms 350ms, -webkit-transform 300ms;
  border: 1px dashed #7f7f7f;
  border-radius: 3px;
  padding: 60px 30px 0px;
  position: relative; }
  .formset__form h3 {
    margin-bottom: 0;
    -webkit-box-ordinal-group: 2;
        -ms-flex-order: 1;
            order: 1;
    margin-left: 13px; }
  .formset__form h3 > .fa {
    margin-right: 10px; }
  .formset__form--edit {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    padding: 0 30px;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: justify;
        -ms-flex-pack: justify;
            justify-content: space-between; }
    .formset__form--edit .formset__button--delete {
      position: relative;
      top: 0;
      right: 0; }

.formset__reorder {
  display: none; }
  .formset__reorder-btn-group {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: end;
        -ms-flex-pack: end;
            justify-content: flex-end;
    margin-bottom: 15px;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center; }
  .formset__reorder + .formset__toggle-switch {
    background: #ddd;
    border-radius: 10px;
    border: 1px solid #bbb;
    padding: 2px;
    -webkit-transition: all .4s ease;
    transition: all .4s ease;
    width: 40px;
    height: 20px;
    cursor: pointer;
    position: relative;
    outline: 0;
    margin-left: 15px;
    margin-bottom: 10px; }
    .formset__reorder + .formset__toggle-switch:after {
      border-radius: 50%;
      background: #fff;
      -webkit-transition: all .2s ease;
      transition: all .2s ease;
      content: '';
      width: 50%;
      height: 100%;
      position: relative;
      left: 0;
      display: block; }
  .formset__reorder:checked + .formset__toggle-switch {
    background: #0084ff; }
  .formset__reorder:checked + .formset__toggle-switch:after {
    left: 50%; }

.formset__form--is-deleted {
  display: none; }

.formset__field {
  margin-bottom: 25px; }

.formset__order {
  position: absolute;
  opacity: 0;
  width: 0;
  height: 0; }

.formset__button--delete {
  cursor: pointer;
  -webkit-box-ordinal-group: 3;
      -ms-flex-order: 2;
          order: 2; }
  .formset__button--delete .fa {
    font-size: 26px; }
  .formset__button--delete input {
    display: none; }

.formset__button--minimize {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  cursor: pointer;
  margin-right: 15px; }

.formset__field--has-add-button {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-direction: row;
          flex-direction: row;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-flex: 1;
      -ms-flex: 1;
          flex: 1; }
  .formset__field--has-add-button label {
    width: 100%;
    -webkit-box-ordinal-group: 1;
        -ms-flex-order: 0;
            order: 0; }
  .formset__field--has-add-button .selectize-control {
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1;
    margin-right: 10px; }
  .formset__field--has-add-button .button {
    -webkit-box-flex: 0;
        -ms-flex-positive: 0;
            flex-grow: 0;
    text-transform: capitalize; }

.sweet-btn {
  margin-bottom: 30px; }

.formset__actions {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
      -ms-flex-pack: end;
          justify-content: flex-end;
  position: absolute;
  right: 15px;
  top: 15px; }

.ui-dialog {
  padding: 10px;
  z-index: 4; }
  .ui-dialog .ui-dialog-content {
    padding: 0; }
  .ui-dialog .ui-corner-all {
    border-radius: 0; }
  .ui-dialog .ui-dialog-titlebar {
    padding: 0; }
  .ui-dialog .ui-dialog-titlebar-close {
    background: #b8b8b8;
    padding: 15px;
    right: 10px;
    top: 20px;
    min-width: auto;
    z-index: 1; }
    .ui-dialog .ui-dialog-titlebar-close, .ui-dialog .ui-dialog-titlebar-close:hover {
      border: none; }
    .ui-dialog .ui-dialog-titlebar-close:before {
      content: '\F00D';
      font: normal 20px/1 FontAwesome;
      color: #fff;
      position: absolute;
      left: 8px;
      top: 5px;
      text-indent: 0; }
    .ui-dialog .ui-dialog-titlebar-close span {
      display: none; }
    .ui-dialog .ui-dialog-titlebar-close:hover {
      background: #666; }

.ui-dialog-titlebar {
  position: static !important; }

.ui-widget-overlay {
  position: fixed;
  background: #eee;
  opacity: .7;
  height: 100%; }

.ui-widget-header {
  background: none;
  border: none; }

.frame-wrapper {
  position: relative;
  padding-bottom: 52%;
  padding-top: 30px;
  height: 0;
  overflow: hidden;
  z-index: 10; }
  .frame-wrapper iframe,
  .frame-wrapper object,
  .frame-wrapper embed {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%; }
  @media screen and (max-width: 700px) {
    .frame-wrapper {
      position: relative;
      padding-bottom: 47%;
      padding-top: 30px;
      height: 0;
      overflow: hidden; } }

.modal__frameWrap {
  height: 100%;
  width: 100%;
  position: absolute;
  top: 0;
  overflow: hidden; }

body.modal__body {
  background: none;
  border: none;
  overflow: auto; }
  body.modal__body #main {
    -webkit-box-shadow: none;
            box-shadow: none;
    padding: 0;
    border-top: 0; }
    body.modal__body #main:before {
      display: none; }
  body.modal__body #container {
    padding-bottom: 0; }

:root {
  --blue: #39f; }

.cropper-container {
  font-size: 0;
  line-height: 0;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  direction: ltr;
  -ms-touch-action: none;
      touch-action: none; }
  .cropper-container img {
    /* Avoid margin top issue (Occur only when margin-top <= -height) */
    display: block;
    min-width: 0 !important;
    max-width: none !important;
    min-height: 0 !important;
    max-height: none !important;
    width: 100%;
    height: 100%;
    image-orientation: 0deg; }

.cropper-wrap-box,
.cropper-canvas,
.cropper-drag-box,
.cropper-crop-box,
.cropper-modal {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0; }

.cropper-wrap-box {
  overflow: hidden; }

.cropper-drag-box {
  opacity: 0;
  background-color: #fff; }

.cropper-modal {
  opacity: .5;
  background-color: #000; }

.cropper-view-box {
  display: block;
  overflow: hidden;
  width: 100%;
  height: 100%;
  outline: 1px solid var(--blue);
  outline-color: color(var(--blue) opacity(75%)); }

.cropper-dashed {
  position: absolute;
  display: block;
  opacity: .5;
  border: 0 dashed #eee; }
  .cropper-dashed.dashed-h {
    top: 33.33333333%;
    left: 0;
    width: 100%;
    height: 33.33333333%;
    border-top-width: 1px;
    border-bottom-width: 1px; }
  .cropper-dashed.dashed-v {
    top: 0;
    left: 33.33333333%;
    width: 33.33333333%;
    height: 100%;
    border-right-width: 1px;
    border-left-width: 1px; }

.cropper-center {
  position: absolute;
  top: 50%;
  left: 50%;
  display: block;
  width: 0;
  height: 0;
  opacity: .75; }
  .cropper-center:before, .cropper-center:after {
    position: absolute;
    display: block;
    content: ' ';
    background-color: #eee; }
  .cropper-center:before {
    top: 0;
    left: -3px;
    width: 7px;
    height: 1px; }
  .cropper-center:after {
    top: -3px;
    left: 0;
    width: 1px;
    height: 7px; }

.cropper-face,
.cropper-line,
.cropper-point {
  position: absolute;
  display: block;
  width: 100%;
  height: 100%;
  opacity: .1; }

.cropper-face {
  top: 0;
  left: 0;
  background-color: #fff; }

.cropper-line {
  background-color: var(--blue); }
  .cropper-line.line-e {
    top: 0;
    right: -3px;
    width: 5px;
    cursor: e-resize; }
  .cropper-line.line-n {
    top: -3px;
    left: 0;
    height: 5px;
    cursor: n-resize; }
  .cropper-line.line-w {
    top: 0;
    left: -3px;
    width: 5px;
    cursor: w-resize; }
  .cropper-line.line-s {
    bottom: -3px;
    left: 0;
    height: 5px;
    cursor: s-resize; }

.cropper-point {
  width: 5px;
  height: 5px;
  opacity: .75;
  background-color: var(--blue); }
  .cropper-point.point-e {
    top: 50%;
    right: -3px;
    margin-top: -3px;
    cursor: e-resize; }
  .cropper-point.point-n {
    top: -3px;
    left: 50%;
    margin-left: -3px;
    cursor: n-resize; }
  .cropper-point.point-w {
    top: 50%;
    left: -3px;
    margin-top: -3px;
    cursor: w-resize; }
  .cropper-point.point-s {
    bottom: -3px;
    left: 50%;
    margin-left: -3px;
    cursor: s-resize; }
  .cropper-point.point-ne {
    top: -3px;
    right: -3px;
    cursor: ne-resize; }
  .cropper-point.point-nw {
    top: -3px;
    left: -3px;
    cursor: nw-resize; }
  .cropper-point.point-sw {
    bottom: -3px;
    left: -3px;
    cursor: sw-resize; }
  .cropper-point.point-se {
    right: -3px;
    bottom: -3px;
    width: 20px;
    height: 20px;
    cursor: se-resize;
    opacity: 1; }
    @media (min-width: 768px) {
      .cropper-point.point-se {
        width: 15px;
        height: 15px; } }
    @media (min-width: 992px) {
      .cropper-point.point-se {
        width: 10px;
        height: 10px; } }
    @media (min-width: 1200px) {
      .cropper-point.point-se {
        width: 5px;
        height: 5px;
        opacity: .75; } }
  .cropper-point.point-se:before {
    position: absolute;
    right: -50%;
    bottom: -50%;
    display: block;
    width: 200%;
    height: 200%;
    content: ' ';
    opacity: 0;
    background-color: var(--blue); }

.cropper-invisible {
  opacity: 0; }

.cropper-bg {
  background-image: inline("../images/bg.png"); }

.cropper-hide {
  position: absolute;
  display: block;
  width: 0;
  height: 0; }

.cropper-hidden {
  display: none !important; }

.cropper-move {
  cursor: move; }

.cropper-crop {
  cursor: crosshair; }

.cropper-disabled .cropper-drag-box,
.cropper-disabled .cropper-face,
.cropper-disabled .cropper-line,
.cropper-disabled .cropper-point {
  cursor: not-allowed; }

.image-cropper {
  margin-top: 30px;
  height: 60vh; }
  .image-cropper img {
    max-width: 100%; }
  .image-cropper h3 strong {
    text-transform: none; }
  .image-cropper__container {
    height: 60vh; }

.image-cropper__preview {
  overflow: hidden;
  padding: 0;
  width: 600px;
  height: auto; }

.selectize-control.single .selectize-input:after,
.selectize-control.single .selectize-input.dropdown-active:after {
  content: '\F078';
  color: #b8b8b8;
  font-family: 'FontAwesome';
  display: block;
  border: none;
  margin: 0;
  top: 13px;
  right: 13px;
  width: auto;
  height: auto;
  -webkit-transition: -webkit-transform 150ms;
  transition: -webkit-transform 150ms;
  transition: transform 150ms;
  transition: transform 150ms, -webkit-transform 150ms; }

.selectize-control.single .selectize-input.dropdown-active:after {
  color: #f00;
  -webkit-transform: scaleY(-1);
          transform: scaleY(-1); }

.select2-container,
.selectize-input,
.selectize-control.single .selectize-input,
.selectize-dropdown.single,
.selectize-control.single .selectize-input.input-active {
  background-color: #eee; }

.select2-container,
.selectize-control {
  min-width: 200px; }

.selectize-input.dropdown-active {
  border-radius: 0; }

.selectize-input.focus {
  -webkit-box-shadow: none;
          box-shadow: none; }

.selectize-control,
.selectize-input {
  height: 40px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }

.selectize-control.single .selectize-input,
.selectize-dropdown.single,
.selectize-dropdown,
.selectize-input {
  border: none;
  border-radius: 0;
  -webkit-box-shadow: none;
          box-shadow: none;
  color: #191919; }
  .selectize-control.single .selectize-input input, .selectize-control.single .selectize-input input::-webkit-input-placeholder, .selectize-control.single .selectize-input input:-moz-placeholder, .selectize-control.single .selectize-input input::-moz-placeholder, .selectize-control.single .selectize-input input:-ms-input-placeholder,
  .selectize-dropdown.single input,
  .selectize-dropdown.single input::-webkit-input-placeholder,
  .selectize-dropdown.single input:-moz-placeholder,
  .selectize-dropdown.single input::-moz-placeholder,
  .selectize-dropdown.single input:-ms-input-placeholder,
  .selectize-dropdown input,
  .selectize-dropdown input::-webkit-input-placeholder,
  .selectize-dropdown input:-moz-placeholder,
  .selectize-dropdown input::-moz-placeholder,
  .selectize-dropdown input:-ms-input-placeholder,
  .selectize-input input,
  .selectize-input input::-webkit-input-placeholder,
  .selectize-input input:-moz-placeholder,
  .selectize-input input::-moz-placeholder,
  .selectize-input input:-ms-input-placeholder {
    display: inline-block;
    color: #191919;
    top: 4px;
    position: relative; }

.selectize-dropdown.single,
.selectize-dropdown.multi {
  margin-top: 10px;
  border: 1px solid #eee; }

.selectize-dropdown-content {
  border: 1px solid #eee; }
  .selectize-dropdown-content > div {
    background-color: #fff; }

.selectize-control.single .selectize-input,
.selectize-dropdown.single {
  background-image: none; }

.create--hide {
  display: none; }

.select-asset__item {
  position: relative; }

.select-asset__caption {
  position: absolute;
  top: 50%;
  -webkit-transform: translateY(-50%);
          transform: translateY(-50%); }

.select-asset__image--thumb {
  width: 50px;
  height: 50px;
  background-size: cover;
  display: inline-block;
  margin-right: 10px; }

.selectize-control.multi .selectize-input [data-value], .selectize-control.multi .selectize-input [data-value].active {
  -webkit-box-shadow: none;
          box-shadow: none;
  background-image: none;
  background-color: #fff;
  border-radius: 0;
  border: none;
  text-shadow: none;
  color: #0084ff; }

.selectize-control.multi .selectize-input [data-value] .remove {
  border: none;
  color: #b8b8b8;
  font-size: 20px;
  padding: 3px 4px 0 0; }
  .selectize-control.multi .selectize-input [data-value] .remove:hover {
    background-color: #fff;
    color: #f00; }

.selectize-control.multi .selectize-input > div {
  position: relative;
  margin: 0 8px 3px 0;
  padding: 6px 16px 6px 12px; }
  .selectize-control.multi .selectize-input > div:hover i {
    opacity: 1; }
  .selectize-control.multi .selectize-input > div i {
    position: absolute;
    -webkit-transition: opacity 350ms;
    transition: opacity 350ms;
    opacity: 0;
    top: 0;
    right: 0;
    padding: 2px; }

.select-asset__item {
  position: relative; }

.select-asset__caption {
  position: absolute;
  top: 50%;
  -webkit-transform: translateY(-50%);
          transform: translateY(-50%); }

.select-asset__image--thumb {
  width: 50px;
  height: 50px;
  background-size: cover;
  display: inline-block;
  margin-right: 10px; }

.ui-datepicker {
  z-index: 3 !important; }

/* timepicker add-on
----------------------------------*/
.ui-timepicker-div .ui_tpicker_time {
  display: none; }

.ui-timepicker-div .ui_tpicker_time_label {
  display: block;
  float: none;
  background: #DDD;
  border: 1px solid #DDD;
  margin-bottom: 10px;
  padding: 5px;
  text-align: center;
  font-weight: bold; }

.ui-timepicker-div {
  background: #fff; }

.ui-timepicker-div .ui-widget-header {
  margin-bottom: 8px; }

.ui-timepicker-div dl {
  background: #F6F6F6;
  text-align: left;
  padding-bottom: 5px;
  margin: 5px 0; }

.ui-timepicker-div dl dt {
  float: left;
  clear: left;
  padding: 0 0 0 5px; }

.ui-timepicker-div dl dd {
  margin: 0 10px 10px 25%; }

.ui-timepicker-div td {
  font-size: 90%; }

.ui-tpicker-grid-label {
  background: none;
  border: none;
  margin: 0;
  padding: 0; }

.ui-timepicker-rtl {
  direction: rtl; }

.ui-timepicker-rtl dl {
  text-align: right;
  padding: 10px 5px 0 0; }

.ui-timepicker-rtl dl dt {
  float: right;
  clear: right; }

.ui-timepicker-rtl dl dd {
  margin: 0 25% 10px 10px; }

.ui-datepicker-calendar thead tr th {
  font-size: 14px; }

.ui-datepicker-calendar tbody tr td,
.ui-datepicker-calendar tbody tr:nth-child(odd) td,
.ui-datepicker-calendar tbody tr:hover td {
  background: #fff; }

.ui_tpicker_hour_label,
.ui_tpicker_minute_label,
.ui_tpicker_second_label {
  font-weight: bold;
  font-size: 14px; }

/*! jQuery UI - v1.9.2 - 2013-12-11
* http://jqueryui.com
* Includes: jquery.ui.core.css,
jquery.ui.datepicker.css,
jquery.ui.slider.css,
jquery.ui.theme.css
* To view and modify this theme,
visit http://jqueryui.com/themeroller/?ffDefault=Helvetica%2CArial%2Csans-serif&fwDefault=bold&fsDefault=1.1em&cornerRadius=2px&bgColorHeader=dddddd&bgTextureHeader=highlight_soft&bgImgOpacityHeader=50&borderColorHeader=dddddd&fcHeader=444444&iconColorHeader=0073ea&bgColorContent=ffffff&bgTextureContent=flat&bgImgOpacityContent=75&borderColorContent=dddddd&fcContent=444444&iconColorContent=ff0000&bgColorDefault=f6f6f6&bgTextureDefault=highlight_soft&bgImgOpacityDefault=100&borderColorDefault=dddddd&fcDefault=0073ea&iconColorDefault=666666&bgColorHover=0073ea&bgTextureHover=highlight_soft&bgImgOpacityHover=25&borderColorHover=0073ea&fcHover=ffffff&iconColorHover=ffffff&bgColorActive=ffffff&bgTextureActive=glass&bgImgOpacityActive=65&borderColorActive=dddddd&fcActive=ff0000&iconColorActive=454545&bgColorHighlight=ffffff&bgTextureHighlight=flat&bgImgOpacityHighlight=55&borderColorHighlight=cccccc&fcHighlight=444444&iconColorHighlight=0073ea&bgColorError=ffffff&bgTextureError=flat&bgImgOpacityError=55&borderColorError=ff0000&fcError=222222&iconColorError=ff0000&bgColorOverlay=eeeeee&bgTextureOverlay=flat&bgImgOpacityOverlay=0&opacityOverlay=80&bgColorShadow=aaaaaa&bgTextureShadow=flat&bgImgOpacityShadow=0&opacityShadow=60&thicknessShadow=4px&offsetTopShadow=-4px&offsetLeftShadow=-4px&cornerRadiusShadow=0px
* Copyright 2013 jQuery Foundation and other contributors;
  Licensed MIT */
/* Layout helpers
----------------------------------*/
.ui-helper-hidden {
  display: none; }

.ui-helper-hidden-accessible {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px; }

.ui-helper-reset {
  margin: 0;
  padding: 0;
  border: 0;
  outline: 0;
  line-height: 1.3;
  text-decoration: none;
  font-size: 100%;
  list-style: none; }

.ui-helper-clearfix:before,
.ui-helper-clearfix:after {
  content: "";
  display: table; }

.ui-helper-clearfix:after {
  clear: both; }

.ui-helper-clearfix {
  zoom: 1; }

.ui-helper-zfix {
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  position: absolute;
  opacity: 0;
  filter: Alpha(Opacity=0); }

/* Interaction Cues
----------------------------------*/
.ui-state-disabled {
  cursor: default !important; }

/* Icons
----------------------------------*/
/* states and images */
.ui-icon {
  display: block;
  text-indent: -99999px;
  overflow: hidden;
  background-repeat: no-repeat; }

/* Overlays */
.ui-widget-overlay {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%; }

.ui-datepicker {
  width: 17em;
  padding: .2em .2em 0;
  display: none; }

.ui-datepicker-header {
  position: relative;
  margin-bottom: 20px; }

.ui-datepicker .ui-datepicker-prev,
.ui-datepicker .ui-datepicker-next {
  cursor: pointer;
  position: absolute;
  top: 6px;
  width: 1.8em;
  height: 1.8em;
  z-index: 1; }
  .ui-datepicker .ui-datepicker-prev:after,
  .ui-datepicker .ui-datepicker-next:after {
    color: #0084ff;
    font: normal 20px/1 FontAwesome; }
  .ui-datepicker .ui-datepicker-prev.ui-state-hover,
  .ui-datepicker .ui-datepicker-next.ui-state-hover {
    border: none;
    background: transparent; }

.ui-datepicker .ui-datepicker-prev {
  left: 2px; }
  .ui-datepicker .ui-datepicker-prev:after {
    content: "\F104"; }

.ui-datepicker .ui-datepicker-next {
  right: 2px;
  text-align: right; }
  .ui-datepicker .ui-datepicker-next:after {
    content: "\F105"; }

.ui-datepicker .ui-datepicker-prev span,
.ui-datepicker .ui-datepicker-next span {
  display: none; }

.ui-datepicker .ui-datepicker-title {
  margin: 0 2.3em;
  line-height: 1.8em;
  text-align: center; }

.ui-datepicker .ui-datepicker-title select {
  font-size: 1em;
  margin: 1px 0; }

.ui-datepicker select.ui-datepicker-month-year {
  width: 100%; }

.ui-datepicker select.ui-datepicker-month,
.ui-datepicker select.ui-datepicker-year {
  width: 49%; }

.ui-datepicker-year {
  font-weight: normal; }

.ui-datepicker tr, .ui-datepicker tr:first-of-type:not(:only-child), .ui-datepicker tr:last-of-type:not(:only-child),
.ui-datepicker td,
.ui-datepicker td:first-of-type:not(:only-child),
.ui-datepicker td:last-of-type:not(:only-child) {
  padding: 0; }

.ui-datepicker tr:hover,
.ui-datepicker td:hover {
  background: none; }

.ui-datepicker td span,
.ui-datepicker td a {
  padding: 7px; }

.ui-datepicker-calendar thead {
  border: none; }

.ui-datepicker table {
  border: none;
  width: 100%;
  font-size: .9em;
  border-collapse: collapse;
  margin-bottom: 20px; }

.ui-datepicker th {
  color: #b8b8b8;
  text-align: center;
  font-weight: bold;
  border: 0; }
  .ui-datepicker th, .ui-datepicker th:first-of-type:not(:only-child), .ui-datepicker th:last-of-type:not(:only-child) {
    padding: .7em .3em; }

.ui-datepicker td {
  border: 0;
  padding: 1px; }

.ui-datepicker td span,
.ui-datepicker td a {
  display: block;
  padding: 9px;
  text-align: center;
  text-decoration: none; }

.ui-datepicker .ui-datepicker-buttonpane {
  background-image: none;
  margin: .7em 0 0 0;
  padding: 0 .2em;
  border-left: 0;
  border-right: 0;
  border-bottom: 0; }

.ui-datepicker .ui-datepicker-buttonpane button {
  float: right;
  margin: .5em .2em .4em;
  cursor: pointer;
  padding: .2em .6em .3em .6em;
  width: auto;
  overflow: visible; }

.ui-datepicker .ui-datepicker-buttonpane button.ui-datepicker-current {
  float: left; }

/* IE6 IFRAME FIX (taken from datepicker 1.5.3 */
.ui-datepicker-cover {
  position: absolute;
  /*must have*/
  z-index: -1;
  /*must have*/
  -webkit-filter: mask();
          filter: mask();
  /*must have*/
  top: -4px;
  /*must have*/
  left: -4px;
  /*must have*/
  width: 200px;
  /*must have*/
  height: 200px;
  /*must have*/ }

.ui-slider {
  position: relative;
  text-align: left; }

.ui-slider .ui-slider-handle {
  position: absolute;
  z-index: 2;
  width: 1.2em;
  height: 1.2em;
  cursor: default; }

.ui-slider .ui-slider-range {
  position: absolute;
  z-index: 1;
  font-size: .7em;
  display: block;
  border: 0;
  background-position: 0 0; }

.ui-slider-horizontal {
  height: .8em; }

.ui-slider-horizontal .ui-slider-handle {
  top: -.3em;
  margin-left: -.6em; }

.ui-slider-horizontal .ui-slider-range {
  top: 0;
  height: 100%; }

.ui-slider-horizontal .ui-slider-range-min {
  left: 0; }

.ui-slider-horizontal .ui-slider-range-max {
  right: 0; }

.ui-slider-vertical {
  width: .8em;
  height: 100px; }

.ui-slider-vertical .ui-slider-handle {
  left: -.3em;
  margin-left: 0;
  margin-bottom: -.6em; }

.ui-slider-vertical .ui-slider-range {
  left: 0;
  width: 100%; }

.ui-slider-vertical .ui-slider-range-min {
  bottom: 0; }

.ui-slider-vertical .ui-slider-range-max {
  top: 0; }

.ui-state-highlight {
  background-color: #0084ff;
  color: #fff; }

/* Component containers
----------------------------------*/
.ui-widget {
  font-family: Helvetica,Arial,sans-serif;
  font-size: 1.1em; }

.ui-widget .ui-widget {
  font-size: 1em; }

.ui-widget input,
.ui-widget select,
.ui-widget textarea,
.ui-widget button {
  font-family: Helvetica,Arial,sans-serif;
  font-size: 1em; }

/* Interaction states
----------------------------------*/
.ui-state-default,
.ui-widget-content .ui-state-default,
.ui-widget-header .ui-state-default {
  border: none;
  background: #eee;
  color: #191919; }

.ui-state-default a,
.ui-state-default a:link,
.ui-state-default a:visited {
  color: #191919;
  text-decoration: none; }

.ui-state-hover,
.ui-state-active,
.ui-widget-content .ui-state-hover,
.ui-widget-header .ui-state-hover,
.ui-state-focus,
.ui-widget-content .ui-state-focus,
.ui-widget-header .ui-state-focus {
  background: #0084ff;
  font-weight: bold;
  color: #fff; }

.ui-state-hover a,
.ui-state-hover a:hover,
.ui-state-hover a:link,
.ui-state-hover a:visited {
  color: #fff;
  text-decoration: none; }

.ui-state-active,
.ui-widget-content .ui-state-active,
.ui-widget-header .ui-state-active {
  background: #0084ff;
  font-weight: bold;
  color: #fff; }

.ui-state-active a,
.ui-state-active a:link,
.ui-state-active a:visited {
  color: #fff;
  text-decoration: none; }

.ui-widget-content.ui-slider {
  background: #eee;
  border: none;
  height: 7px; }

.ui-slider-handle.ui-state-default {
  background-color: #0084ff;
  border: none;
  border-radius: 50%;
  width: 20px;
  height: 20px; }
  .ui-slider-handle.ui-state-default:focus {
    outline: none; }

.ui-timepicker-div .ui_tpicker_time_label,
.ui-timepicker-div dl {
  border: none;
  background: #fff; }
  .ui-timepicker-div .ui_tpicker_time_label .timezone,
  .ui-timepicker-div dl .timezone {
    font-weight: normal; }

.ui-timepicker-div dl dd.ui_tpicker_hour {
  margin-bottom: 20px; }

/* Corner radius */
.ui-corner-all,
.ui-corner-top,
.ui-corner-left,
.ui-corner-tl {
  border-top-left-radius: 2px; }

.ui-corner-all,
.ui-corner-top,
.ui-corner-right,
.ui-corner-tr {
  border-top-right-radius: 2px; }

.ui-corner-all,
.ui-corner-bottom,
.ui-corner-left,
.ui-corner-bl {
  border-bottom-left-radius: 2px; }

.ui-corner-all,
.ui-corner-bottom,
.ui-corner-right,
.ui-corner-br {
  border-bottom-right-radius: 2px; }

/* Overlays */
.ui-widget-overlay {
  background: #eeeeee;
  opacity: .8;
  filter: Alpha(Opacity=80); }

.ui-widget-shadow {
  margin: -4px 0 0 -4px;
  padding: 4px;
  background: #aaaaaa;
  opacity: .6;
  filter: Alpha(Opacity=60);
  border-radius: 0px; }

.insert-media {
  padding: 10px 0 0; }

.publish input[type=radio] {
  display: inline-block; }

.publish .hasDatepicker {
  display: none; }

.publish input[name="when_rdi"]:checked + input {
  display: block;
  max-width: 250px; }

/*# sourceMappingURL=main.css.map*/